# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

try:
    from ._models_py3 import (
        AKS,
        AADAuthTypeWorkspaceConnectionProperties,
        AccessKeyAuthTypeWorkspaceConnectionProperties,
        AccountApiKeys,
        AccountKeyAuthTypeWorkspaceConnectionProperties,
        AccountKeyDatastoreCredentials,
        AccountKeyDatastoreSecrets,
        AccountModel,
        AcrDetails,
        ActualCapacityInfo,
        AksComputeSecrets,
        AksComputeSecretsProperties,
        AksNetworkingConfiguration,
        AKSSchema,
        AKSSchemaProperties,
        AllFeatures,
        AllNodes,
        AmlCompute,
        AmlComputeNodeInformation,
        AmlComputeNodesInformation,
        AmlComputeProperties,
        AmlComputeSchema,
        AmlToken,
        AmlTokenComputeIdentity,
        AmlUserFeature,
        AnonymousAccessCredential,
        ApiKeyAuthWorkspaceConnectionProperties,
        ArmResourceId,
        AssetBase,
        AssetContainer,
        AssetJobInput,
        AssetJobOutput,
        AssetReferenceBase,
        AssignedUser,
        AutoDeleteSetting,
        AutoForecastHorizon,
        AutologgerSettings,
        AutoMLJob,
        AutoMLVertical,
        AutoNCrossValidations,
        AutoPauseProperties,
        AutoScaleProperties,
        AutoSeasonality,
        AutoTargetLags,
        AutoTargetRollingWindowSize,
        AzureBlobDatastore,
        AzureDataLakeGen1Datastore,
        AzureDataLakeGen2Datastore,
        AzureDatastore,
        AzureDevOpsWebhook,
        AzureFileDatastore,
        AzureMLBatchInferencingServer,
        AzureMLOnlineInferencingServer,
        AzureOpenAiFineTuning,
        AzureOpenAiHyperParameters,
        BanditPolicy,
        BaseEnvironmentId,
        BaseEnvironmentSource,
        BatchDeployment,
        BatchDeploymentConfiguration,
        BatchDeploymentProperties,
        BatchDeploymentTrackedResourceArmPaginatedResult,
        BatchEndpoint,
        BatchEndpointDefaults,
        BatchEndpointProperties,
        BatchEndpointTrackedResourceArmPaginatedResult,
        BatchPipelineComponentDeploymentConfiguration,
        BatchRetrySettings,
        BayesianSamplingAlgorithm,
        BindOptions,
        BlobReferenceForConsumptionDto,
        BuildContext,
        CallRateLimit,
        CapacityConfig,
        CapacityReservationGroup,
        CapacityReservationGroupProperties,
        CapacityReservationGroupTrackedResourceArmPaginatedResult,
        CategoricalDataDriftMetricThreshold,
        CategoricalDataQualityMetricThreshold,
        CategoricalPredictionDriftMetricThreshold,
        CertificateDatastoreCredentials,
        CertificateDatastoreSecrets,
        Classification,
        ClassificationModelPerformanceMetricThreshold,
        ClassificationTrainingSettings,
        ClusterUpdateParameters,
        CocoExportSummary,
        CodeConfiguration,
        CodeContainer,
        CodeContainerProperties,
        CodeContainerResourceArmPaginatedResult,
        CodeVersion,
        CodeVersionProperties,
        CodeVersionResourceArmPaginatedResult,
        CognitiveServiceEndpointDeploymentResourceProperties,
        CognitiveServicesSku,
        Collection,
        ColumnTransformer,
        CommandJob,
        CommandJobLimits,
        ComponentConfiguration,
        ComponentContainer,
        ComponentContainerProperties,
        ComponentContainerResourceArmPaginatedResult,
        ComponentVersion,
        ComponentVersionProperties,
        ComponentVersionResourceArmPaginatedResult,
        Compute,
        ComputeInstance,
        ComputeInstanceApplication,
        ComputeInstanceAutologgerSettings,
        ComputeInstanceConnectivityEndpoints,
        ComputeInstanceContainer,
        ComputeInstanceCreatedBy,
        ComputeInstanceDataDisk,
        ComputeInstanceDataMount,
        ComputeInstanceEnvironmentInfo,
        ComputeInstanceLastOperation,
        ComputeInstanceProperties,
        ComputeInstanceSchema,
        ComputeInstanceSshSettings,
        ComputeInstanceVersion,
        ComputeRecurrenceSchedule,
        ComputeResource,
        ComputeResourceSchema,
        ComputeRuntimeDto,
        ComputeSchedules,
        ComputeSecrets,
        ComputeStartStopSchedule,
        ContainerResourceRequirements,
        ContainerResourceSettings,
        ContentSafetyEndpointDeploymentResourceProperties,
        ContentSafetyEndpointResourceProperties,
        CosmosDbSettings,
        CreateMonitorAction,
        Cron,
        CronTrigger,
        CsvExportSummary,
        CustomForecastHorizon,
        CustomInferencingServer,
        CustomKeys,
        CustomKeysWorkspaceConnectionProperties,
        CustomMetricThreshold,
        CustomModelFineTuning,
        CustomModelJobInput,
        CustomModelJobOutput,
        CustomMonitoringSignal,
        CustomNCrossValidations,
        CustomSeasonality,
        CustomService,
        CustomTargetLags,
        CustomTargetRollingWindowSize,
        DatabaseSource,
        Databricks,
        DatabricksComputeSecrets,
        DatabricksComputeSecretsProperties,
        DatabricksProperties,
        DatabricksSchema,
        DataCollector,
        DataContainer,
        DataContainerProperties,
        DataContainerResourceArmPaginatedResult,
        DataDriftMetricThresholdBase,
        DataDriftMonitoringSignal,
        DataFactory,
        DataImport,
        DataImportSource,
        DataLakeAnalytics,
        DataLakeAnalyticsSchema,
        DataLakeAnalyticsSchemaProperties,
        DataPathAssetReference,
        DataQualityMetricThresholdBase,
        DataQualityMonitoringSignal,
        DataReferenceCredential,
        DatasetExportSummary,
        Datastore,
        DatastoreCredentials,
        DatastoreProperties,
        DatastoreResourceArmPaginatedResult,
        DatastoreSecrets,
        DataVersionBase,
        DataVersionBaseProperties,
        DataVersionBaseResourceArmPaginatedResult,
        DefaultScaleSettings,
        DeploymentLogs,
        DeploymentLogsRequest,
        DeploymentModel,
        DeploymentResourceConfiguration,
        DestinationAsset,
        DiagnoseRequestProperties,
        DiagnoseResponseResult,
        DiagnoseResponseResultValue,
        DiagnoseResult,
        DiagnoseWorkspaceParameters,
        DistributionConfiguration,
        Docker,
        DockerCredential,
        EarlyTerminationPolicy,
        EncryptionKeyVaultUpdateProperties,
        EncryptionProperty,
        EncryptionUpdateProperties,
        Endpoint,
        EndpointAuthKeys,
        EndpointAuthToken,
        EndpointDeploymentModel,
        EndpointDeploymentPropertiesBase,
        EndpointDeploymentResourceProperties,
        EndpointDeploymentResourcePropertiesBasicResource,
        EndpointDeploymentResourcePropertiesBasicResourceArmPaginatedResult,
        EndpointKeys,
        EndpointModels,
        EndpointPropertiesBase,
        EndpointResourceProperties,
        EndpointResourcePropertiesBasicResource,
        EndpointResourcePropertiesBasicResourceArmPaginatedResult,
        EndpointScheduleAction,
        EnvironmentContainer,
        EnvironmentContainerProperties,
        EnvironmentContainerResourceArmPaginatedResult,
        EnvironmentVariable,
        EnvironmentVersion,
        EnvironmentVersionProperties,
        EnvironmentVersionResourceArmPaginatedResult,
        ErrorAdditionalInfo,
        ErrorDetail,
        ErrorResponse,
        EstimatedVMPrice,
        EstimatedVMPrices,
        ExportSummary,
        ExternalFQDNResponse,
        Feature,
        FeatureAttributionDriftMonitoringSignal,
        FeatureAttributionMetricThreshold,
        FeatureImportanceSettings,
        FeatureProperties,
        FeatureResourceArmPaginatedResult,
        FeaturesetContainer,
        FeaturesetContainerProperties,
        FeaturesetContainerResourceArmPaginatedResult,
        FeaturesetSpecification,
        FeaturesetVersion,
        FeaturesetVersionBackfillRequest,
        FeaturesetVersionBackfillResponse,
        FeaturesetVersionProperties,
        FeaturesetVersionResourceArmPaginatedResult,
        FeaturestoreEntityContainer,
        FeaturestoreEntityContainerProperties,
        FeaturestoreEntityContainerResourceArmPaginatedResult,
        FeaturestoreEntityVersion,
        FeaturestoreEntityVersionProperties,
        FeaturestoreEntityVersionResourceArmPaginatedResult,
        FeatureStoreSettings,
        FeatureSubset,
        FeatureWindow,
        FeaturizationSettings,
        FileSystemSource,
        FineTuningJob,
        FineTuningVertical,
        FixedInputData,
        FlavorData,
        ForecastHorizon,
        Forecasting,
        ForecastingSettings,
        ForecastingTrainingSettings,
        FQDNEndpoint,
        FQDNEndpointDetail,
        FQDNEndpoints,
        FQDNEndpointsPropertyBag,
        FqdnOutboundRule,
        GenerationSafetyQualityMetricThreshold,
        GenerationSafetyQualityMonitoringSignal,
        GenerationTokenUsageMetricThreshold,
        GenerationTokenUsageSignal,
        GetBlobReferenceForConsumptionDto,
        GetBlobReferenceSASRequestDto,
        GetBlobReferenceSASResponseDto,
        GridSamplingAlgorithm,
        GroupStatus,
        HdfsDatastore,
        HDInsight,
        HDInsightProperties,
        HDInsightSchema,
        IdAssetReference,
        IdentityConfiguration,
        IdentityForCmk,
        IdleShutdownSetting,
        Image,
        ImageClassification,
        ImageClassificationBase,
        ImageClassificationMultilabel,
        ImageInstanceSegmentation,
        ImageLimitSettings,
        ImageMetadata,
        ImageModelDistributionSettings,
        ImageModelDistributionSettingsClassification,
        ImageModelDistributionSettingsObjectDetection,
        ImageModelSettings,
        ImageModelSettingsClassification,
        ImageModelSettingsObjectDetection,
        ImageObjectDetection,
        ImageObjectDetectionBase,
        ImageSweepSettings,
        ImageVertical,
        ImportDataAction,
        IndexColumn,
        InferenceContainerProperties,
        InferenceEndpoint,
        InferenceEndpointProperties,
        InferenceEndpointTrackedResourceArmPaginatedResult,
        InferenceGroup,
        InferenceGroupProperties,
        InferenceGroupTrackedResourceArmPaginatedResult,
        InferencePool,
        InferencePoolProperties,
        InferencePoolTrackedResourceArmPaginatedResult,
        InferencingServer,
        InstanceTypeSchema,
        InstanceTypeSchemaResources,
        IntellectualProperty,
        JobBase,
        JobBaseProperties,
        JobBaseResourceArmPaginatedResult,
        JobInput,
        JobLimits,
        JobOutput,
        JobResourceConfiguration,
        JobScheduleAction,
        JobService,
        JupyterKernelConfig,
        KerberosCredentials,
        KerberosKeytabCredentials,
        KerberosKeytabSecrets,
        KerberosPasswordCredentials,
        KerberosPasswordSecrets,
        KeyVaultProperties,
        Kubernetes,
        KubernetesOnlineDeployment,
        KubernetesProperties,
        KubernetesSchema,
        LabelCategory,
        LabelClass,
        LabelingDataConfiguration,
        LabelingJob,
        LabelingJobImageProperties,
        LabelingJobInstructions,
        LabelingJobMediaProperties,
        LabelingJobProperties,
        LabelingJobResourceArmPaginatedResult,
        LabelingJobTextProperties,
        LakeHouseArtifact,
        ListAmlUserFeatureResult,
        ListNotebookKeysResult,
        ListStorageAccountKeysResult,
        ListUsagesResult,
        ListWorkspaceKeysResult,
        ListWorkspaceQuotas,
        LiteralJobInput,
        ManagedComputeIdentity,
        ManagedIdentity,
        ManagedIdentityAuthTypeWorkspaceConnectionProperties,
        ManagedIdentityCredential,
        ManagedNetworkProvisionOptions,
        ManagedNetworkProvisionStatus,
        ManagedNetworkSettings,
        ManagedOnlineDeployment,
        ManagedOnlineEndpointDeploymentResourceProperties,
        ManagedOnlineEndpointResourceProperties,
        ManagedResourceGroupAssignedIdentities,
        ManagedResourceGroupSettings,
        ManagedServiceIdentity,
        MarketplacePlan,
        MarketplaceSubscription,
        MarketplaceSubscriptionProperties,
        MarketplaceSubscriptionResourceArmPaginatedResult,
        MaterializationComputeResource,
        MaterializationSettings,
        MedianStoppingPolicy,
        MLAssistConfiguration,
        MLAssistConfigurationDisabled,
        MLAssistConfigurationEnabled,
        MLFlowModelJobInput,
        MLFlowModelJobOutput,
        MLTableData,
        MLTableJobInput,
        MLTableJobOutput,
        ModelConfiguration,
        ModelContainer,
        ModelContainerProperties,
        ModelContainerResourceArmPaginatedResult,
        ModelDeprecationInfo,
        ModelPackageInput,
        ModelPerformanceMetricThresholdBase,
        ModelPerformanceSignal,
        ModelSettings,
        ModelSku,
        ModelVersion,
        ModelVersionProperties,
        ModelVersionResourceArmPaginatedResult,
        MonitorComputeConfigurationBase,
        MonitorComputeIdentityBase,
        MonitorDefinition,
        MonitorEmailNotificationSettings,
        MonitoringDataSegment,
        MonitoringFeatureFilterBase,
        MonitoringInputDataBase,
        MonitoringSignalBase,
        MonitoringTarget,
        MonitoringThreshold,
        MonitoringWorkspaceConnection,
        MonitorNotificationSettings,
        MonitorServerlessSparkCompute,
        Mpi,
        NCrossValidations,
        NlpFixedParameters,
        NlpParameterSubspace,
        NlpSweepSettings,
        NlpVertical,
        NlpVerticalFeaturizationSettings,
        NlpVerticalLimitSettings,
        Nodes,
        NodeStateCounts,
        NoneAuthTypeWorkspaceConnectionProperties,
        NoneDatastoreCredentials,
        NotebookAccessTokenResult,
        NotebookPreparationError,
        NotebookResourceInfo,
        NotificationSetting,
        NumericalDataDriftMetricThreshold,
        NumericalDataQualityMetricThreshold,
        NumericalPredictionDriftMetricThreshold,
        OAuth2AuthTypeWorkspaceConnectionProperties,
        Objective,
        OneLakeArtifact,
        OneLakeDatastore,
        OnlineDeployment,
        OnlineDeploymentProperties,
        OnlineDeploymentTrackedResourceArmPaginatedResult,
        OnlineEndpoint,
        OnlineEndpointProperties,
        OnlineEndpointTrackedResourceArmPaginatedResult,
        OnlineInferenceConfiguration,
        OnlineRequestSettings,
        OnlineScaleSettings,
        OpenAIEndpointDeploymentResourceProperties,
        OpenAIEndpointResourceProperties,
        Operation,
        OperationDisplay,
        OperationListResult,
        OsPatchingStatus,
        OutboundRule,
        OutboundRuleBasicResource,
        OutboundRuleListResult,
        OutputPathAssetReference,
        PackageInputPathBase,
        PackageInputPathId,
        PackageInputPathUrl,
        PackageInputPathVersion,
        PackageRequest,
        PackageResponse,
        PaginatedComputeResourcesList,
        PartialBatchDeployment,
        PartialBatchDeploymentPartialMinimalTrackedResourceWithProperties,
        PartialJobBase,
        PartialJobBasePartialResource,
        PartialManagedServiceIdentity,
        PartialMinimalTrackedResource,
        PartialMinimalTrackedResourceWithIdentity,
        PartialMinimalTrackedResourceWithSku,
        PartialMinimalTrackedResourceWithSkuAndIdentity,
        PartialNotificationSetting,
        PartialRegistryPartialTrackedResource,
        PartialSku,
        Password,
        PATAuthTypeWorkspaceConnectionProperties,
        PendingUploadCredentialDto,
        PendingUploadRequestDto,
        PendingUploadResponseDto,
        PersonalComputeInstanceSettings,
        PipelineJob,
        PoolEnvironmentConfiguration,
        PoolModelConfiguration,
        PoolStatus,
        PredictionDriftMetricThresholdBase,
        PredictionDriftMonitoringSignal,
        PrivateEndpoint,
        PrivateEndpointConnection,
        PrivateEndpointConnectionListResult,
        PrivateEndpointDestination,
        PrivateEndpointOutboundRule,
        PrivateEndpointResource,
        PrivateLinkResource,
        PrivateLinkResourceListResult,
        PrivateLinkServiceConnectionState,
        ProbeSettings,
        ProgressMetrics,
        PropertiesBase,
        ProxyResource,
        PyTorch,
        QueueSettings,
        QuotaBaseProperties,
        QuotaUpdateParameters,
        RandomSamplingAlgorithm,
        Ray,
        Recurrence,
        RecurrenceSchedule,
        RecurrenceTrigger,
        RegenerateEndpointKeysRequest,
        RegenerateServiceAccountKeyContent,
        Registry,
        RegistryListCredentialsResult,
        RegistryPartialManagedServiceIdentity,
        RegistryPrivateEndpointConnection,
        RegistryPrivateLinkServiceConnectionState,
        RegistryRegionArmDetails,
        RegistryTrackedResourceArmPaginatedResult,
        Regression,
        RegressionModelPerformanceMetricThreshold,
        RegressionTrainingSettings,
        RequestConfiguration,
        RequestLogging,
        RequestMatchPattern,
        ResizeSchema,
        Resource,
        ResourceBase,
        ResourceConfiguration,
        ResourceId,
        ResourceName,
        ResourceQuota,
        RollingInputData,
        Route,
        SamplingAlgorithm,
        SASAuthTypeWorkspaceConnectionProperties,
        SASCredential,
        SASCredentialDto,
        SasDatastoreCredentials,
        SasDatastoreSecrets,
        ScaleSettings,
        ScaleSettingsInformation,
        Schedule,
        ScheduleActionBase,
        ScheduleBase,
        ScheduleProperties,
        ScheduleResourceArmPaginatedResult,
        ScriptReference,
        ScriptsToExecute,
        Seasonality,
        SecretConfiguration,
        ServerlessComputeSettings,
        ServerlessEndpoint,
        ServerlessEndpointCapacityReservation,
        ServerlessEndpointProperties,
        ServerlessEndpointStatus,
        ServerlessEndpointTrackedResourceArmPaginatedResult,
        ServerlessInferenceEndpoint,
        ServerlessOffer,
        ServiceManagedResourcesSettings,
        ServicePrincipalAuthTypeWorkspaceConnectionProperties,
        ServicePrincipalDatastoreCredentials,
        ServicePrincipalDatastoreSecrets,
        ServiceTagDestination,
        ServiceTagOutboundRule,
        SetupScripts,
        SharedPrivateLinkResource,
        Sku,
        SkuCapacity,
        SkuResource,
        SkuResourceArmPaginatedResult,
        SkuSetting,
        SparkJob,
        SparkJobEntry,
        SparkJobPythonEntry,
        SparkJobScalaEntry,
        SparkResourceConfiguration,
        SpeechEndpointDeploymentResourceProperties,
        SpeechEndpointResourceProperties,
        SslConfiguration,
        StackEnsembleSettings,
        StaticInputData,
        StatusMessage,
        StorageAccountDetails,
        SweepJob,
        SweepJobLimits,
        SynapseSpark,
        SynapseSparkProperties,
        SystemCreatedAcrAccount,
        SystemCreatedStorageAccount,
        SystemData,
        SystemService,
        TableFixedParameters,
        TableParameterSubspace,
        TableSweepSettings,
        TableVertical,
        TableVerticalFeaturizationSettings,
        TableVerticalLimitSettings,
        TargetLags,
        TargetRollingWindowSize,
        TargetUtilizationScaleSettings,
        TensorFlow,
        TextClassification,
        TextClassificationMultilabel,
        TextNer,
        ThrottlingRule,
        TmpfsOptions,
        TopNFeaturesByAttribution,
        TrackedResource,
        TrainingSettings,
        TrialComponent,
        TriggerBase,
        TriggerOnceRequest,
        TriggerRunSubmissionDto,
        TritonInferencingServer,
        TritonModelJobInput,
        TritonModelJobOutput,
        TruncationSelectionPolicy,
        UpdateWorkspaceQuotas,
        UpdateWorkspaceQuotasResult,
        UriFileDataVersion,
        UriFileJobInput,
        UriFileJobOutput,
        UriFolderDataVersion,
        UriFolderJobInput,
        UriFolderJobOutput,
        Usage,
        UsageName,
        UserAccountCredentials,
        UserAssignedIdentity,
        UserCreatedAcrAccount,
        UserCreatedStorageAccount,
        UserIdentity,
        UsernamePasswordAuthTypeWorkspaceConnectionProperties,
        VirtualMachine,
        VirtualMachineImage,
        VirtualMachineSchema,
        VirtualMachineSchemaProperties,
        VirtualMachineSecrets,
        VirtualMachineSecretsSchema,
        VirtualMachineSize,
        VirtualMachineSizeListResult,
        VirtualMachineSshCredentials,
        VolumeDefinition,
        VolumeOptions,
        Webhook,
        Workspace,
        WorkspaceConnectionAccessKey,
        WorkspaceConnectionApiKey,
        WorkspaceConnectionManagedIdentity,
        WorkspaceConnectionOAuth2,
        WorkspaceConnectionPersonalAccessToken,
        WorkspaceConnectionPropertiesV2,
        WorkspaceConnectionPropertiesV2BasicResource,
        WorkspaceConnectionPropertiesV2BasicResourceArmPaginatedResult,
        WorkspaceConnectionServicePrincipal,
        WorkspaceConnectionSharedAccessSignature,
        WorkspaceConnectionUpdateParameter,
        WorkspaceConnectionUsernamePassword,
        WorkspaceHubConfig,
        WorkspaceListResult,
        WorkspacePrivateEndpointResource,
        WorkspaceUpdateParameters,
    )
except (SyntaxError, ImportError):
    from ._models import AADAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import AKS  # type: ignore
    from ._models import AKSSchema  # type: ignore
    from ._models import AKSSchemaProperties  # type: ignore
    from ._models import AccessKeyAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import AccountApiKeys  # type: ignore
    from ._models import AccountKeyAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import AccountKeyDatastoreCredentials  # type: ignore
    from ._models import AccountKeyDatastoreSecrets  # type: ignore
    from ._models import AccountModel  # type: ignore
    from ._models import AcrDetails  # type: ignore
    from ._models import ActualCapacityInfo  # type: ignore
    from ._models import AksComputeSecrets  # type: ignore
    from ._models import AksComputeSecretsProperties  # type: ignore
    from ._models import AksNetworkingConfiguration  # type: ignore
    from ._models import AllFeatures  # type: ignore
    from ._models import AllNodes  # type: ignore
    from ._models import AmlCompute  # type: ignore
    from ._models import AmlComputeNodeInformation  # type: ignore
    from ._models import AmlComputeNodesInformation  # type: ignore
    from ._models import AmlComputeProperties  # type: ignore
    from ._models import AmlComputeSchema  # type: ignore
    from ._models import AmlToken  # type: ignore
    from ._models import AmlTokenComputeIdentity  # type: ignore
    from ._models import AmlUserFeature  # type: ignore
    from ._models import AnonymousAccessCredential  # type: ignore
    from ._models import ApiKeyAuthWorkspaceConnectionProperties  # type: ignore
    from ._models import ArmResourceId  # type: ignore
    from ._models import AssetBase  # type: ignore
    from ._models import AssetContainer  # type: ignore
    from ._models import AssetJobInput  # type: ignore
    from ._models import AssetJobOutput  # type: ignore
    from ._models import AssetReferenceBase  # type: ignore
    from ._models import AssignedUser  # type: ignore
    from ._models import AutoDeleteSetting  # type: ignore
    from ._models import AutoForecastHorizon  # type: ignore
    from ._models import AutoMLJob  # type: ignore
    from ._models import AutoMLVertical  # type: ignore
    from ._models import AutoNCrossValidations  # type: ignore
    from ._models import AutoPauseProperties  # type: ignore
    from ._models import AutoScaleProperties  # type: ignore
    from ._models import AutoSeasonality  # type: ignore
    from ._models import AutoTargetLags  # type: ignore
    from ._models import AutoTargetRollingWindowSize  # type: ignore
    from ._models import AutologgerSettings  # type: ignore
    from ._models import AzureBlobDatastore  # type: ignore
    from ._models import AzureDataLakeGen1Datastore  # type: ignore
    from ._models import AzureDataLakeGen2Datastore  # type: ignore
    from ._models import AzureDatastore  # type: ignore
    from ._models import AzureDevOpsWebhook  # type: ignore
    from ._models import AzureFileDatastore  # type: ignore
    from ._models import AzureMLBatchInferencingServer  # type: ignore
    from ._models import AzureMLOnlineInferencingServer  # type: ignore
    from ._models import AzureOpenAiFineTuning  # type: ignore
    from ._models import AzureOpenAiHyperParameters  # type: ignore
    from ._models import BanditPolicy  # type: ignore
    from ._models import BaseEnvironmentId  # type: ignore
    from ._models import BaseEnvironmentSource  # type: ignore
    from ._models import BatchDeployment  # type: ignore
    from ._models import BatchDeploymentConfiguration  # type: ignore
    from ._models import BatchDeploymentProperties  # type: ignore
    from ._models import BatchDeploymentTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import BatchEndpoint  # type: ignore
    from ._models import BatchEndpointDefaults  # type: ignore
    from ._models import BatchEndpointProperties  # type: ignore
    from ._models import BatchEndpointTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import BatchPipelineComponentDeploymentConfiguration  # type: ignore
    from ._models import BatchRetrySettings  # type: ignore
    from ._models import BayesianSamplingAlgorithm  # type: ignore
    from ._models import BindOptions  # type: ignore
    from ._models import BlobReferenceForConsumptionDto  # type: ignore
    from ._models import BuildContext  # type: ignore
    from ._models import CallRateLimit  # type: ignore
    from ._models import CapacityConfig  # type: ignore
    from ._models import CapacityReservationGroup  # type: ignore
    from ._models import CapacityReservationGroupProperties  # type: ignore
    from ._models import CapacityReservationGroupTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import CategoricalDataDriftMetricThreshold  # type: ignore
    from ._models import CategoricalDataQualityMetricThreshold  # type: ignore
    from ._models import CategoricalPredictionDriftMetricThreshold  # type: ignore
    from ._models import CertificateDatastoreCredentials  # type: ignore
    from ._models import CertificateDatastoreSecrets  # type: ignore
    from ._models import Classification  # type: ignore
    from ._models import ClassificationModelPerformanceMetricThreshold  # type: ignore
    from ._models import ClassificationTrainingSettings  # type: ignore
    from ._models import ClusterUpdateParameters  # type: ignore
    from ._models import CocoExportSummary  # type: ignore
    from ._models import CodeConfiguration  # type: ignore
    from ._models import CodeContainer  # type: ignore
    from ._models import CodeContainerProperties  # type: ignore
    from ._models import CodeContainerResourceArmPaginatedResult  # type: ignore
    from ._models import CodeVersion  # type: ignore
    from ._models import CodeVersionProperties  # type: ignore
    from ._models import CodeVersionResourceArmPaginatedResult  # type: ignore
    from ._models import CognitiveServiceEndpointDeploymentResourceProperties  # type: ignore
    from ._models import CognitiveServicesSku  # type: ignore
    from ._models import Collection  # type: ignore
    from ._models import ColumnTransformer  # type: ignore
    from ._models import CommandJob  # type: ignore
    from ._models import CommandJobLimits  # type: ignore
    from ._models import ComponentConfiguration  # type: ignore
    from ._models import ComponentContainer  # type: ignore
    from ._models import ComponentContainerProperties  # type: ignore
    from ._models import ComponentContainerResourceArmPaginatedResult  # type: ignore
    from ._models import ComponentVersion  # type: ignore
    from ._models import ComponentVersionProperties  # type: ignore
    from ._models import ComponentVersionResourceArmPaginatedResult  # type: ignore
    from ._models import Compute  # type: ignore
    from ._models import ComputeInstance  # type: ignore
    from ._models import ComputeInstanceApplication  # type: ignore
    from ._models import ComputeInstanceAutologgerSettings  # type: ignore
    from ._models import ComputeInstanceConnectivityEndpoints  # type: ignore
    from ._models import ComputeInstanceContainer  # type: ignore
    from ._models import ComputeInstanceCreatedBy  # type: ignore
    from ._models import ComputeInstanceDataDisk  # type: ignore
    from ._models import ComputeInstanceDataMount  # type: ignore
    from ._models import ComputeInstanceEnvironmentInfo  # type: ignore
    from ._models import ComputeInstanceLastOperation  # type: ignore
    from ._models import ComputeInstanceProperties  # type: ignore
    from ._models import ComputeInstanceSchema  # type: ignore
    from ._models import ComputeInstanceSshSettings  # type: ignore
    from ._models import ComputeInstanceVersion  # type: ignore
    from ._models import ComputeRecurrenceSchedule  # type: ignore
    from ._models import ComputeResource  # type: ignore
    from ._models import ComputeResourceSchema  # type: ignore
    from ._models import ComputeRuntimeDto  # type: ignore
    from ._models import ComputeSchedules  # type: ignore
    from ._models import ComputeSecrets  # type: ignore
    from ._models import ComputeStartStopSchedule  # type: ignore
    from ._models import ContainerResourceRequirements  # type: ignore
    from ._models import ContainerResourceSettings  # type: ignore
    from ._models import ContentSafetyEndpointDeploymentResourceProperties  # type: ignore
    from ._models import ContentSafetyEndpointResourceProperties  # type: ignore
    from ._models import CosmosDbSettings  # type: ignore
    from ._models import CreateMonitorAction  # type: ignore
    from ._models import Cron  # type: ignore
    from ._models import CronTrigger  # type: ignore
    from ._models import CsvExportSummary  # type: ignore
    from ._models import CustomForecastHorizon  # type: ignore
    from ._models import CustomInferencingServer  # type: ignore
    from ._models import CustomKeys  # type: ignore
    from ._models import CustomKeysWorkspaceConnectionProperties  # type: ignore
    from ._models import CustomMetricThreshold  # type: ignore
    from ._models import CustomModelFineTuning  # type: ignore
    from ._models import CustomModelJobInput  # type: ignore
    from ._models import CustomModelJobOutput  # type: ignore
    from ._models import CustomMonitoringSignal  # type: ignore
    from ._models import CustomNCrossValidations  # type: ignore
    from ._models import CustomSeasonality  # type: ignore
    from ._models import CustomService  # type: ignore
    from ._models import CustomTargetLags  # type: ignore
    from ._models import CustomTargetRollingWindowSize  # type: ignore
    from ._models import DataCollector  # type: ignore
    from ._models import DataContainer  # type: ignore
    from ._models import DataContainerProperties  # type: ignore
    from ._models import DataContainerResourceArmPaginatedResult  # type: ignore
    from ._models import DataDriftMetricThresholdBase  # type: ignore
    from ._models import DataDriftMonitoringSignal  # type: ignore
    from ._models import DataFactory  # type: ignore
    from ._models import DataImport  # type: ignore
    from ._models import DataImportSource  # type: ignore
    from ._models import DataLakeAnalytics  # type: ignore
    from ._models import DataLakeAnalyticsSchema  # type: ignore
    from ._models import DataLakeAnalyticsSchemaProperties  # type: ignore
    from ._models import DataPathAssetReference  # type: ignore
    from ._models import DataQualityMetricThresholdBase  # type: ignore
    from ._models import DataQualityMonitoringSignal  # type: ignore
    from ._models import DataReferenceCredential  # type: ignore
    from ._models import DataVersionBase  # type: ignore
    from ._models import DataVersionBaseProperties  # type: ignore
    from ._models import DataVersionBaseResourceArmPaginatedResult  # type: ignore
    from ._models import DatabaseSource  # type: ignore
    from ._models import Databricks  # type: ignore
    from ._models import DatabricksComputeSecrets  # type: ignore
    from ._models import DatabricksComputeSecretsProperties  # type: ignore
    from ._models import DatabricksProperties  # type: ignore
    from ._models import DatabricksSchema  # type: ignore
    from ._models import DatasetExportSummary  # type: ignore
    from ._models import Datastore  # type: ignore
    from ._models import DatastoreCredentials  # type: ignore
    from ._models import DatastoreProperties  # type: ignore
    from ._models import DatastoreResourceArmPaginatedResult  # type: ignore
    from ._models import DatastoreSecrets  # type: ignore
    from ._models import DefaultScaleSettings  # type: ignore
    from ._models import DeploymentLogs  # type: ignore
    from ._models import DeploymentLogsRequest  # type: ignore
    from ._models import DeploymentModel  # type: ignore
    from ._models import DeploymentResourceConfiguration  # type: ignore
    from ._models import DestinationAsset  # type: ignore
    from ._models import DiagnoseRequestProperties  # type: ignore
    from ._models import DiagnoseResponseResult  # type: ignore
    from ._models import DiagnoseResponseResultValue  # type: ignore
    from ._models import DiagnoseResult  # type: ignore
    from ._models import DiagnoseWorkspaceParameters  # type: ignore
    from ._models import DistributionConfiguration  # type: ignore
    from ._models import Docker  # type: ignore
    from ._models import DockerCredential  # type: ignore
    from ._models import EarlyTerminationPolicy  # type: ignore
    from ._models import EncryptionKeyVaultUpdateProperties  # type: ignore
    from ._models import EncryptionProperty  # type: ignore
    from ._models import EncryptionUpdateProperties  # type: ignore
    from ._models import Endpoint  # type: ignore
    from ._models import EndpointAuthKeys  # type: ignore
    from ._models import EndpointAuthToken  # type: ignore
    from ._models import EndpointDeploymentModel  # type: ignore
    from ._models import EndpointDeploymentPropertiesBase  # type: ignore
    from ._models import EndpointDeploymentResourceProperties  # type: ignore
    from ._models import EndpointDeploymentResourcePropertiesBasicResource  # type: ignore
    from ._models import EndpointDeploymentResourcePropertiesBasicResourceArmPaginatedResult  # type: ignore
    from ._models import EndpointKeys  # type: ignore
    from ._models import EndpointModels  # type: ignore
    from ._models import EndpointPropertiesBase  # type: ignore
    from ._models import EndpointResourceProperties  # type: ignore
    from ._models import EndpointResourcePropertiesBasicResource  # type: ignore
    from ._models import EndpointResourcePropertiesBasicResourceArmPaginatedResult  # type: ignore
    from ._models import EndpointScheduleAction  # type: ignore
    from ._models import EnvironmentContainer  # type: ignore
    from ._models import EnvironmentContainerProperties  # type: ignore
    from ._models import EnvironmentContainerResourceArmPaginatedResult  # type: ignore
    from ._models import EnvironmentVariable  # type: ignore
    from ._models import EnvironmentVersion  # type: ignore
    from ._models import EnvironmentVersionProperties  # type: ignore
    from ._models import EnvironmentVersionResourceArmPaginatedResult  # type: ignore
    from ._models import ErrorAdditionalInfo  # type: ignore
    from ._models import ErrorDetail  # type: ignore
    from ._models import ErrorResponse  # type: ignore
    from ._models import EstimatedVMPrice  # type: ignore
    from ._models import EstimatedVMPrices  # type: ignore
    from ._models import ExportSummary  # type: ignore
    from ._models import ExternalFQDNResponse  # type: ignore
    from ._models import FQDNEndpoint  # type: ignore
    from ._models import FQDNEndpointDetail  # type: ignore
    from ._models import FQDNEndpoints  # type: ignore
    from ._models import FQDNEndpointsPropertyBag  # type: ignore
    from ._models import Feature  # type: ignore
    from ._models import FeatureAttributionDriftMonitoringSignal  # type: ignore
    from ._models import FeatureAttributionMetricThreshold  # type: ignore
    from ._models import FeatureImportanceSettings  # type: ignore
    from ._models import FeatureProperties  # type: ignore
    from ._models import FeatureResourceArmPaginatedResult  # type: ignore
    from ._models import FeatureStoreSettings  # type: ignore
    from ._models import FeatureSubset  # type: ignore
    from ._models import FeatureWindow  # type: ignore
    from ._models import FeaturesetContainer  # type: ignore
    from ._models import FeaturesetContainerProperties  # type: ignore
    from ._models import FeaturesetContainerResourceArmPaginatedResult  # type: ignore
    from ._models import FeaturesetSpecification  # type: ignore
    from ._models import FeaturesetVersion  # type: ignore
    from ._models import FeaturesetVersionBackfillRequest  # type: ignore
    from ._models import FeaturesetVersionBackfillResponse  # type: ignore
    from ._models import FeaturesetVersionProperties  # type: ignore
    from ._models import FeaturesetVersionResourceArmPaginatedResult  # type: ignore
    from ._models import FeaturestoreEntityContainer  # type: ignore
    from ._models import FeaturestoreEntityContainerProperties  # type: ignore
    from ._models import FeaturestoreEntityContainerResourceArmPaginatedResult  # type: ignore
    from ._models import FeaturestoreEntityVersion  # type: ignore
    from ._models import FeaturestoreEntityVersionProperties  # type: ignore
    from ._models import FeaturestoreEntityVersionResourceArmPaginatedResult  # type: ignore
    from ._models import FeaturizationSettings  # type: ignore
    from ._models import FileSystemSource  # type: ignore
    from ._models import FineTuningJob  # type: ignore
    from ._models import FineTuningVertical  # type: ignore
    from ._models import FixedInputData  # type: ignore
    from ._models import FlavorData  # type: ignore
    from ._models import ForecastHorizon  # type: ignore
    from ._models import Forecasting  # type: ignore
    from ._models import ForecastingSettings  # type: ignore
    from ._models import ForecastingTrainingSettings  # type: ignore
    from ._models import FqdnOutboundRule  # type: ignore
    from ._models import GenerationSafetyQualityMetricThreshold  # type: ignore
    from ._models import GenerationSafetyQualityMonitoringSignal  # type: ignore
    from ._models import GenerationTokenUsageMetricThreshold  # type: ignore
    from ._models import GenerationTokenUsageSignal  # type: ignore
    from ._models import GetBlobReferenceForConsumptionDto  # type: ignore
    from ._models import GetBlobReferenceSASRequestDto  # type: ignore
    from ._models import GetBlobReferenceSASResponseDto  # type: ignore
    from ._models import GridSamplingAlgorithm  # type: ignore
    from ._models import GroupStatus  # type: ignore
    from ._models import HDInsight  # type: ignore
    from ._models import HDInsightProperties  # type: ignore
    from ._models import HDInsightSchema  # type: ignore
    from ._models import HdfsDatastore  # type: ignore
    from ._models import IdAssetReference  # type: ignore
    from ._models import IdentityConfiguration  # type: ignore
    from ._models import IdentityForCmk  # type: ignore
    from ._models import IdleShutdownSetting  # type: ignore
    from ._models import Image  # type: ignore
    from ._models import ImageClassification  # type: ignore
    from ._models import ImageClassificationBase  # type: ignore
    from ._models import ImageClassificationMultilabel  # type: ignore
    from ._models import ImageInstanceSegmentation  # type: ignore
    from ._models import ImageLimitSettings  # type: ignore
    from ._models import ImageMetadata  # type: ignore
    from ._models import ImageModelDistributionSettings  # type: ignore
    from ._models import ImageModelDistributionSettingsClassification  # type: ignore
    from ._models import ImageModelDistributionSettingsObjectDetection  # type: ignore
    from ._models import ImageModelSettings  # type: ignore
    from ._models import ImageModelSettingsClassification  # type: ignore
    from ._models import ImageModelSettingsObjectDetection  # type: ignore
    from ._models import ImageObjectDetection  # type: ignore
    from ._models import ImageObjectDetectionBase  # type: ignore
    from ._models import ImageSweepSettings  # type: ignore
    from ._models import ImageVertical  # type: ignore
    from ._models import ImportDataAction  # type: ignore
    from ._models import IndexColumn  # type: ignore
    from ._models import InferenceContainerProperties  # type: ignore
    from ._models import InferenceEndpoint  # type: ignore
    from ._models import InferenceEndpointProperties  # type: ignore
    from ._models import InferenceEndpointTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import InferenceGroup  # type: ignore
    from ._models import InferenceGroupProperties  # type: ignore
    from ._models import InferenceGroupTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import InferencePool  # type: ignore
    from ._models import InferencePoolProperties  # type: ignore
    from ._models import InferencePoolTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import InferencingServer  # type: ignore
    from ._models import InstanceTypeSchema  # type: ignore
    from ._models import InstanceTypeSchemaResources  # type: ignore
    from ._models import IntellectualProperty  # type: ignore
    from ._models import JobBase  # type: ignore
    from ._models import JobBaseProperties  # type: ignore
    from ._models import JobBaseResourceArmPaginatedResult  # type: ignore
    from ._models import JobInput  # type: ignore
    from ._models import JobLimits  # type: ignore
    from ._models import JobOutput  # type: ignore
    from ._models import JobResourceConfiguration  # type: ignore
    from ._models import JobScheduleAction  # type: ignore
    from ._models import JobService  # type: ignore
    from ._models import JupyterKernelConfig  # type: ignore
    from ._models import KerberosCredentials  # type: ignore
    from ._models import KerberosKeytabCredentials  # type: ignore
    from ._models import KerberosKeytabSecrets  # type: ignore
    from ._models import KerberosPasswordCredentials  # type: ignore
    from ._models import KerberosPasswordSecrets  # type: ignore
    from ._models import KeyVaultProperties  # type: ignore
    from ._models import Kubernetes  # type: ignore
    from ._models import KubernetesOnlineDeployment  # type: ignore
    from ._models import KubernetesProperties  # type: ignore
    from ._models import KubernetesSchema  # type: ignore
    from ._models import LabelCategory  # type: ignore
    from ._models import LabelClass  # type: ignore
    from ._models import LabelingDataConfiguration  # type: ignore
    from ._models import LabelingJob  # type: ignore
    from ._models import LabelingJobImageProperties  # type: ignore
    from ._models import LabelingJobInstructions  # type: ignore
    from ._models import LabelingJobMediaProperties  # type: ignore
    from ._models import LabelingJobProperties  # type: ignore
    from ._models import LabelingJobResourceArmPaginatedResult  # type: ignore
    from ._models import LabelingJobTextProperties  # type: ignore
    from ._models import LakeHouseArtifact  # type: ignore
    from ._models import ListAmlUserFeatureResult  # type: ignore
    from ._models import ListNotebookKeysResult  # type: ignore
    from ._models import ListStorageAccountKeysResult  # type: ignore
    from ._models import ListUsagesResult  # type: ignore
    from ._models import ListWorkspaceKeysResult  # type: ignore
    from ._models import ListWorkspaceQuotas  # type: ignore
    from ._models import LiteralJobInput  # type: ignore
    from ._models import MLAssistConfiguration  # type: ignore
    from ._models import MLAssistConfigurationDisabled  # type: ignore
    from ._models import MLAssistConfigurationEnabled  # type: ignore
    from ._models import MLFlowModelJobInput  # type: ignore
    from ._models import MLFlowModelJobOutput  # type: ignore
    from ._models import MLTableData  # type: ignore
    from ._models import MLTableJobInput  # type: ignore
    from ._models import MLTableJobOutput  # type: ignore
    from ._models import ManagedComputeIdentity  # type: ignore
    from ._models import ManagedIdentity  # type: ignore
    from ._models import ManagedIdentityAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import ManagedIdentityCredential  # type: ignore
    from ._models import ManagedNetworkProvisionOptions  # type: ignore
    from ._models import ManagedNetworkProvisionStatus  # type: ignore
    from ._models import ManagedNetworkSettings  # type: ignore
    from ._models import ManagedOnlineDeployment  # type: ignore
    from ._models import ManagedOnlineEndpointDeploymentResourceProperties  # type: ignore
    from ._models import ManagedOnlineEndpointResourceProperties  # type: ignore
    from ._models import ManagedResourceGroupAssignedIdentities  # type: ignore
    from ._models import ManagedResourceGroupSettings  # type: ignore
    from ._models import ManagedServiceIdentity  # type: ignore
    from ._models import MarketplacePlan  # type: ignore
    from ._models import MarketplaceSubscription  # type: ignore
    from ._models import MarketplaceSubscriptionProperties  # type: ignore
    from ._models import MarketplaceSubscriptionResourceArmPaginatedResult  # type: ignore
    from ._models import MaterializationComputeResource  # type: ignore
    from ._models import MaterializationSettings  # type: ignore
    from ._models import MedianStoppingPolicy  # type: ignore
    from ._models import ModelConfiguration  # type: ignore
    from ._models import ModelContainer  # type: ignore
    from ._models import ModelContainerProperties  # type: ignore
    from ._models import ModelContainerResourceArmPaginatedResult  # type: ignore
    from ._models import ModelDeprecationInfo  # type: ignore
    from ._models import ModelPackageInput  # type: ignore
    from ._models import ModelPerformanceMetricThresholdBase  # type: ignore
    from ._models import ModelPerformanceSignal  # type: ignore
    from ._models import ModelSettings  # type: ignore
    from ._models import ModelSku  # type: ignore
    from ._models import ModelVersion  # type: ignore
    from ._models import ModelVersionProperties  # type: ignore
    from ._models import ModelVersionResourceArmPaginatedResult  # type: ignore
    from ._models import MonitorComputeConfigurationBase  # type: ignore
    from ._models import MonitorComputeIdentityBase  # type: ignore
    from ._models import MonitorDefinition  # type: ignore
    from ._models import MonitorEmailNotificationSettings  # type: ignore
    from ._models import MonitorNotificationSettings  # type: ignore
    from ._models import MonitorServerlessSparkCompute  # type: ignore
    from ._models import MonitoringDataSegment  # type: ignore
    from ._models import MonitoringFeatureFilterBase  # type: ignore
    from ._models import MonitoringInputDataBase  # type: ignore
    from ._models import MonitoringSignalBase  # type: ignore
    from ._models import MonitoringTarget  # type: ignore
    from ._models import MonitoringThreshold  # type: ignore
    from ._models import MonitoringWorkspaceConnection  # type: ignore
    from ._models import Mpi  # type: ignore
    from ._models import NCrossValidations  # type: ignore
    from ._models import NlpFixedParameters  # type: ignore
    from ._models import NlpParameterSubspace  # type: ignore
    from ._models import NlpSweepSettings  # type: ignore
    from ._models import NlpVertical  # type: ignore
    from ._models import NlpVerticalFeaturizationSettings  # type: ignore
    from ._models import NlpVerticalLimitSettings  # type: ignore
    from ._models import NodeStateCounts  # type: ignore
    from ._models import Nodes  # type: ignore
    from ._models import NoneAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import NoneDatastoreCredentials  # type: ignore
    from ._models import NotebookAccessTokenResult  # type: ignore
    from ._models import NotebookPreparationError  # type: ignore
    from ._models import NotebookResourceInfo  # type: ignore
    from ._models import NotificationSetting  # type: ignore
    from ._models import NumericalDataDriftMetricThreshold  # type: ignore
    from ._models import NumericalDataQualityMetricThreshold  # type: ignore
    from ._models import NumericalPredictionDriftMetricThreshold  # type: ignore
    from ._models import OAuth2AuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import Objective  # type: ignore
    from ._models import OneLakeArtifact  # type: ignore
    from ._models import OneLakeDatastore  # type: ignore
    from ._models import OnlineDeployment  # type: ignore
    from ._models import OnlineDeploymentProperties  # type: ignore
    from ._models import OnlineDeploymentTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import OnlineEndpoint  # type: ignore
    from ._models import OnlineEndpointProperties  # type: ignore
    from ._models import OnlineEndpointTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import OnlineInferenceConfiguration  # type: ignore
    from ._models import OnlineRequestSettings  # type: ignore
    from ._models import OnlineScaleSettings  # type: ignore
    from ._models import OpenAIEndpointDeploymentResourceProperties  # type: ignore
    from ._models import OpenAIEndpointResourceProperties  # type: ignore
    from ._models import Operation  # type: ignore
    from ._models import OperationDisplay  # type: ignore
    from ._models import OperationListResult  # type: ignore
    from ._models import OsPatchingStatus  # type: ignore
    from ._models import OutboundRule  # type: ignore
    from ._models import OutboundRuleBasicResource  # type: ignore
    from ._models import OutboundRuleListResult  # type: ignore
    from ._models import OutputPathAssetReference  # type: ignore
    from ._models import PATAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import PackageInputPathBase  # type: ignore
    from ._models import PackageInputPathId  # type: ignore
    from ._models import PackageInputPathUrl  # type: ignore
    from ._models import PackageInputPathVersion  # type: ignore
    from ._models import PackageRequest  # type: ignore
    from ._models import PackageResponse  # type: ignore
    from ._models import PaginatedComputeResourcesList  # type: ignore
    from ._models import PartialBatchDeployment  # type: ignore
    from ._models import PartialBatchDeploymentPartialMinimalTrackedResourceWithProperties  # type: ignore
    from ._models import PartialJobBase  # type: ignore
    from ._models import PartialJobBasePartialResource  # type: ignore
    from ._models import PartialManagedServiceIdentity  # type: ignore
    from ._models import PartialMinimalTrackedResource  # type: ignore
    from ._models import PartialMinimalTrackedResourceWithIdentity  # type: ignore
    from ._models import PartialMinimalTrackedResourceWithSku  # type: ignore
    from ._models import PartialMinimalTrackedResourceWithSkuAndIdentity  # type: ignore
    from ._models import PartialNotificationSetting  # type: ignore
    from ._models import PartialRegistryPartialTrackedResource  # type: ignore
    from ._models import PartialSku  # type: ignore
    from ._models import Password  # type: ignore
    from ._models import PendingUploadCredentialDto  # type: ignore
    from ._models import PendingUploadRequestDto  # type: ignore
    from ._models import PendingUploadResponseDto  # type: ignore
    from ._models import PersonalComputeInstanceSettings  # type: ignore
    from ._models import PipelineJob  # type: ignore
    from ._models import PoolEnvironmentConfiguration  # type: ignore
    from ._models import PoolModelConfiguration  # type: ignore
    from ._models import PoolStatus  # type: ignore
    from ._models import PredictionDriftMetricThresholdBase  # type: ignore
    from ._models import PredictionDriftMonitoringSignal  # type: ignore
    from ._models import PrivateEndpoint  # type: ignore
    from ._models import PrivateEndpointConnection  # type: ignore
    from ._models import PrivateEndpointConnectionListResult  # type: ignore
    from ._models import PrivateEndpointDestination  # type: ignore
    from ._models import PrivateEndpointOutboundRule  # type: ignore
    from ._models import PrivateEndpointResource  # type: ignore
    from ._models import PrivateLinkResource  # type: ignore
    from ._models import PrivateLinkResourceListResult  # type: ignore
    from ._models import PrivateLinkServiceConnectionState  # type: ignore
    from ._models import ProbeSettings  # type: ignore
    from ._models import ProgressMetrics  # type: ignore
    from ._models import PropertiesBase  # type: ignore
    from ._models import ProxyResource  # type: ignore
    from ._models import PyTorch  # type: ignore
    from ._models import QueueSettings  # type: ignore
    from ._models import QuotaBaseProperties  # type: ignore
    from ._models import QuotaUpdateParameters  # type: ignore
    from ._models import RandomSamplingAlgorithm  # type: ignore
    from ._models import Ray  # type: ignore
    from ._models import Recurrence  # type: ignore
    from ._models import RecurrenceSchedule  # type: ignore
    from ._models import RecurrenceTrigger  # type: ignore
    from ._models import RegenerateEndpointKeysRequest  # type: ignore
    from ._models import RegenerateServiceAccountKeyContent  # type: ignore
    from ._models import Registry  # type: ignore
    from ._models import RegistryListCredentialsResult  # type: ignore
    from ._models import RegistryPartialManagedServiceIdentity  # type: ignore
    from ._models import RegistryPrivateEndpointConnection  # type: ignore
    from ._models import RegistryPrivateLinkServiceConnectionState  # type: ignore
    from ._models import RegistryRegionArmDetails  # type: ignore
    from ._models import RegistryTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import Regression  # type: ignore
    from ._models import RegressionModelPerformanceMetricThreshold  # type: ignore
    from ._models import RegressionTrainingSettings  # type: ignore
    from ._models import RequestConfiguration  # type: ignore
    from ._models import RequestLogging  # type: ignore
    from ._models import RequestMatchPattern  # type: ignore
    from ._models import ResizeSchema  # type: ignore
    from ._models import Resource  # type: ignore
    from ._models import ResourceBase  # type: ignore
    from ._models import ResourceConfiguration  # type: ignore
    from ._models import ResourceId  # type: ignore
    from ._models import ResourceName  # type: ignore
    from ._models import ResourceQuota  # type: ignore
    from ._models import RollingInputData  # type: ignore
    from ._models import Route  # type: ignore
    from ._models import SASAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import SASCredential  # type: ignore
    from ._models import SASCredentialDto  # type: ignore
    from ._models import SamplingAlgorithm  # type: ignore
    from ._models import SasDatastoreCredentials  # type: ignore
    from ._models import SasDatastoreSecrets  # type: ignore
    from ._models import ScaleSettings  # type: ignore
    from ._models import ScaleSettingsInformation  # type: ignore
    from ._models import Schedule  # type: ignore
    from ._models import ScheduleActionBase  # type: ignore
    from ._models import ScheduleBase  # type: ignore
    from ._models import ScheduleProperties  # type: ignore
    from ._models import ScheduleResourceArmPaginatedResult  # type: ignore
    from ._models import ScriptReference  # type: ignore
    from ._models import ScriptsToExecute  # type: ignore
    from ._models import Seasonality  # type: ignore
    from ._models import SecretConfiguration  # type: ignore
    from ._models import ServerlessComputeSettings  # type: ignore
    from ._models import ServerlessEndpoint  # type: ignore
    from ._models import ServerlessEndpointCapacityReservation  # type: ignore
    from ._models import ServerlessEndpointProperties  # type: ignore
    from ._models import ServerlessEndpointStatus  # type: ignore
    from ._models import ServerlessEndpointTrackedResourceArmPaginatedResult  # type: ignore
    from ._models import ServerlessInferenceEndpoint  # type: ignore
    from ._models import ServerlessOffer  # type: ignore
    from ._models import ServiceManagedResourcesSettings  # type: ignore
    from ._models import ServicePrincipalAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import ServicePrincipalDatastoreCredentials  # type: ignore
    from ._models import ServicePrincipalDatastoreSecrets  # type: ignore
    from ._models import ServiceTagDestination  # type: ignore
    from ._models import ServiceTagOutboundRule  # type: ignore
    from ._models import SetupScripts  # type: ignore
    from ._models import SharedPrivateLinkResource  # type: ignore
    from ._models import Sku  # type: ignore
    from ._models import SkuCapacity  # type: ignore
    from ._models import SkuResource  # type: ignore
    from ._models import SkuResourceArmPaginatedResult  # type: ignore
    from ._models import SkuSetting  # type: ignore
    from ._models import SparkJob  # type: ignore
    from ._models import SparkJobEntry  # type: ignore
    from ._models import SparkJobPythonEntry  # type: ignore
    from ._models import SparkJobScalaEntry  # type: ignore
    from ._models import SparkResourceConfiguration  # type: ignore
    from ._models import SpeechEndpointDeploymentResourceProperties  # type: ignore
    from ._models import SpeechEndpointResourceProperties  # type: ignore
    from ._models import SslConfiguration  # type: ignore
    from ._models import StackEnsembleSettings  # type: ignore
    from ._models import StaticInputData  # type: ignore
    from ._models import StatusMessage  # type: ignore
    from ._models import StorageAccountDetails  # type: ignore
    from ._models import SweepJob  # type: ignore
    from ._models import SweepJobLimits  # type: ignore
    from ._models import SynapseSpark  # type: ignore
    from ._models import SynapseSparkProperties  # type: ignore
    from ._models import SystemCreatedAcrAccount  # type: ignore
    from ._models import SystemCreatedStorageAccount  # type: ignore
    from ._models import SystemData  # type: ignore
    from ._models import SystemService  # type: ignore
    from ._models import TableFixedParameters  # type: ignore
    from ._models import TableParameterSubspace  # type: ignore
    from ._models import TableSweepSettings  # type: ignore
    from ._models import TableVertical  # type: ignore
    from ._models import TableVerticalFeaturizationSettings  # type: ignore
    from ._models import TableVerticalLimitSettings  # type: ignore
    from ._models import TargetLags  # type: ignore
    from ._models import TargetRollingWindowSize  # type: ignore
    from ._models import TargetUtilizationScaleSettings  # type: ignore
    from ._models import TensorFlow  # type: ignore
    from ._models import TextClassification  # type: ignore
    from ._models import TextClassificationMultilabel  # type: ignore
    from ._models import TextNer  # type: ignore
    from ._models import ThrottlingRule  # type: ignore
    from ._models import TmpfsOptions  # type: ignore
    from ._models import TopNFeaturesByAttribution  # type: ignore
    from ._models import TrackedResource  # type: ignore
    from ._models import TrainingSettings  # type: ignore
    from ._models import TrialComponent  # type: ignore
    from ._models import TriggerBase  # type: ignore
    from ._models import TriggerOnceRequest  # type: ignore
    from ._models import TriggerRunSubmissionDto  # type: ignore
    from ._models import TritonInferencingServer  # type: ignore
    from ._models import TritonModelJobInput  # type: ignore
    from ._models import TritonModelJobOutput  # type: ignore
    from ._models import TruncationSelectionPolicy  # type: ignore
    from ._models import UpdateWorkspaceQuotas  # type: ignore
    from ._models import UpdateWorkspaceQuotasResult  # type: ignore
    from ._models import UriFileDataVersion  # type: ignore
    from ._models import UriFileJobInput  # type: ignore
    from ._models import UriFileJobOutput  # type: ignore
    from ._models import UriFolderDataVersion  # type: ignore
    from ._models import UriFolderJobInput  # type: ignore
    from ._models import UriFolderJobOutput  # type: ignore
    from ._models import Usage  # type: ignore
    from ._models import UsageName  # type: ignore
    from ._models import UserAccountCredentials  # type: ignore
    from ._models import UserAssignedIdentity  # type: ignore
    from ._models import UserCreatedAcrAccount  # type: ignore
    from ._models import UserCreatedStorageAccount  # type: ignore
    from ._models import UserIdentity  # type: ignore
    from ._models import UsernamePasswordAuthTypeWorkspaceConnectionProperties  # type: ignore
    from ._models import VirtualMachine  # type: ignore
    from ._models import VirtualMachineImage  # type: ignore
    from ._models import VirtualMachineSchema  # type: ignore
    from ._models import VirtualMachineSchemaProperties  # type: ignore
    from ._models import VirtualMachineSecrets  # type: ignore
    from ._models import VirtualMachineSecretsSchema  # type: ignore
    from ._models import VirtualMachineSize  # type: ignore
    from ._models import VirtualMachineSizeListResult  # type: ignore
    from ._models import VirtualMachineSshCredentials  # type: ignore
    from ._models import VolumeDefinition  # type: ignore
    from ._models import VolumeOptions  # type: ignore
    from ._models import Webhook  # type: ignore
    from ._models import Workspace  # type: ignore
    from ._models import WorkspaceConnectionAccessKey  # type: ignore
    from ._models import WorkspaceConnectionApiKey  # type: ignore
    from ._models import WorkspaceConnectionManagedIdentity  # type: ignore
    from ._models import WorkspaceConnectionOAuth2  # type: ignore
    from ._models import WorkspaceConnectionPersonalAccessToken  # type: ignore
    from ._models import WorkspaceConnectionPropertiesV2  # type: ignore
    from ._models import WorkspaceConnectionPropertiesV2BasicResource  # type: ignore
    from ._models import WorkspaceConnectionPropertiesV2BasicResourceArmPaginatedResult  # type: ignore
    from ._models import WorkspaceConnectionServicePrincipal  # type: ignore
    from ._models import WorkspaceConnectionSharedAccessSignature  # type: ignore
    from ._models import WorkspaceConnectionUpdateParameter  # type: ignore
    from ._models import WorkspaceConnectionUsernamePassword  # type: ignore
    from ._models import WorkspaceHubConfig  # type: ignore
    from ._models import WorkspaceListResult  # type: ignore
    from ._models import WorkspacePrivateEndpointResource  # type: ignore
    from ._models import WorkspaceUpdateParameters  # type: ignore

from ._azure_machine_learning_workspaces_enums import (
    ActionType,
    AllocationState,
    ApplicationSharingPolicy,
    AssetProvisioningState,
    AuthMode,
    AutoDeleteCondition,
    AutoRebuildSetting,
    Autosave,
    BaseEnvironmentSourceType,
    BatchDeploymentConfigurationType,
    BatchLoggingLevel,
    BatchOutputAction,
    BillingCurrency,
    BlockedTransformers,
    Caching,
    CategoricalDataDriftMetric,
    CategoricalDataQualityMetric,
    CategoricalPredictionDriftMetric,
    ClassificationModelPerformanceMetric,
    ClassificationModels,
    ClassificationMultilabelPrimaryMetrics,
    ClassificationPrimaryMetrics,
    ClusterPurpose,
    ComputeInstanceAuthorizationType,
    ComputeInstanceState,
    ComputePowerAction,
    ComputeRecurrenceFrequency,
    ComputeTriggerType,
    ComputeType,
    ComputeWeekDay,
    ConnectionAuthType,
    ConnectionCategory,
    ConnectionGroup,
    ContainerType,
    CreatedByType,
    CredentialsType,
    DataAvailabilityStatus,
    DataCollectionMode,
    DataImportSourceType,
    DataReferenceCredentialType,
    DatastoreType,
    DataType,
    DefaultResourceProvisioningState,
    DeploymentModelVersionUpgradeOption,
    DeploymentProvisioningState,
    DiagnoseResultLevel,
    DistributionType,
    EarlyTerminationPolicyType,
    EgressPublicNetworkAccessType,
    EmailNotificationEnableType,
    EncryptionStatus,
    EndpointAuthMode,
    EndpointComputeType,
    EndpointProvisioningState,
    EndpointServiceConnectionStatus,
    EndpointType,
    EnvironmentType,
    EnvironmentVariableType,
    ExportFormatType,
    FeatureAttributionMetric,
    FeatureDataType,
    FeatureImportanceMode,
    FeatureLags,
    FeaturizationMode,
    FineTuningTaskType,
    ForecastHorizonMode,
    ForecastingModels,
    ForecastingPrimaryMetrics,
    GenerationSafetyQualityMetric,
    GenerationTokenUsageMetric,
    Goal,
    IdentityConfigurationType,
    ImageAnnotationType,
    ImageType,
    IncrementalDataRefresh,
    InferencingServerType,
    InputDeliveryMode,
    InputPathType,
    InstanceSegmentationPrimaryMetrics,
    IsolationMode,
    JobInputType,
    JobLimitsType,
    JobOutputType,
    JobProvisioningState,
    JobStatus,
    JobTier,
    JobType,
    KeyType,
    LearningRateScheduler,
    ListViewType,
    LoadBalancerType,
    LogTrainingMetrics,
    LogValidationLoss,
    LogVerbosity,
    ManagedNetworkStatus,
    ManagedServiceIdentityType,
    MarketplaceSubscriptionProvisioningState,
    MarketplaceSubscriptionStatus,
    MaterializationStoreType,
    MediaType,
    MLAssistConfigurationType,
    MlflowAutologger,
    MLFlowAutologgerState,
    ModelLifecycleStatus,
    ModelProvider,
    ModelSize,
    ModelTaskType,
    MonitorComputeIdentityType,
    MonitorComputeType,
    MonitoringFeatureDataType,
    MonitoringFeatureFilterType,
    MonitoringInputDataType,
    MonitoringModelType,
    MonitoringNotificationType,
    MonitoringSignalType,
    MountAction,
    MountMode,
    MountState,
    MultiSelect,
    NCrossValidationsMode,
    Network,
    NlpLearningRateScheduler,
    NodeState,
    NodesValueType,
    NumericalDataDriftMetric,
    NumericalDataQualityMetric,
    NumericalPredictionDriftMetric,
    ObjectDetectionPrimaryMetrics,
    OneLakeArtifactType,
    OperatingSystemType,
    OperationName,
    OperationStatus,
    OperationTrigger,
    OrderString,
    Origin,
    OsType,
    OutputDeliveryMode,
    PackageBuildState,
    PackageInputDeliveryMode,
    PackageInputType,
    PatchStatus,
    PendingUploadCredentialType,
    PendingUploadType,
    PoolProvisioningState,
    PrivateEndpointConnectionProvisioningState,
    ProtectionLevel,
    Protocol,
    ProvisioningState,
    ProvisioningStatus,
    PublicNetworkAccessType,
    QuotaUnit,
    RandomSamplingAlgorithmRule,
    RecurrenceFrequency,
    ReferenceType,
    RegressionModelPerformanceMetric,
    RegressionModels,
    RegressionPrimaryMetrics,
    RemoteLoginPortPublicAccess,
    RollingRateType,
    RuleAction,
    RuleCategory,
    RuleStatus,
    RuleType,
    SamplingAlgorithmType,
    ScaleType,
    ScheduleActionType,
    ScheduleListViewType,
    ScheduleProvisioningState,
    ScheduleProvisioningStatus,
    ScheduleStatus,
    ScheduleType,
    SeasonalityMode,
    SecretsType,
    ServerlessEndpointState,
    ServerlessInferenceEndpointAuthMode,
    ServiceAccountKeyName,
    ServiceDataAccessAuthIdentity,
    ShortSeriesHandlingConfiguration,
    SkuScaleType,
    SkuTier,
    SourceType,
    SparkJobEntryType,
    SshPublicAccess,
    SslConfigStatus,
    StackMetaLearnerType,
    Status,
    StatusMessageLevel,
    StochasticOptimizer,
    StorageAccountType,
    TargetAggregationFunction,
    TargetLagsMode,
    TargetRollingWindowSizeMode,
    TaskType,
    TextAnnotationType,
    TrainingMode,
    TriggerType,
    UnderlyingResourceAction,
    UnitOfMeasure,
    UsageUnit,
    UseStl,
    ValidationMetricType,
    VMPriceOSType,
    VmPriority,
    VMTier,
    VolumeDefinitionType,
    WebhookType,
    WeekDay,
)

__all__ = [
    'AADAuthTypeWorkspaceConnectionProperties',
    'AKS',
    'AKSSchema',
    'AKSSchemaProperties',
    'AccessKeyAuthTypeWorkspaceConnectionProperties',
    'AccountApiKeys',
    'AccountKeyAuthTypeWorkspaceConnectionProperties',
    'AccountKeyDatastoreCredentials',
    'AccountKeyDatastoreSecrets',
    'AccountModel',
    'AcrDetails',
    'ActualCapacityInfo',
    'AksComputeSecrets',
    'AksComputeSecretsProperties',
    'AksNetworkingConfiguration',
    'AllFeatures',
    'AllNodes',
    'AmlCompute',
    'AmlComputeNodeInformation',
    'AmlComputeNodesInformation',
    'AmlComputeProperties',
    'AmlComputeSchema',
    'AmlToken',
    'AmlTokenComputeIdentity',
    'AmlUserFeature',
    'AnonymousAccessCredential',
    'ApiKeyAuthWorkspaceConnectionProperties',
    'ArmResourceId',
    'AssetBase',
    'AssetContainer',
    'AssetJobInput',
    'AssetJobOutput',
    'AssetReferenceBase',
    'AssignedUser',
    'AutoDeleteSetting',
    'AutoForecastHorizon',
    'AutoMLJob',
    'AutoMLVertical',
    'AutoNCrossValidations',
    'AutoPauseProperties',
    'AutoScaleProperties',
    'AutoSeasonality',
    'AutoTargetLags',
    'AutoTargetRollingWindowSize',
    'AutologgerSettings',
    'AzureBlobDatastore',
    'AzureDataLakeGen1Datastore',
    'AzureDataLakeGen2Datastore',
    'AzureDatastore',
    'AzureDevOpsWebhook',
    'AzureFileDatastore',
    'AzureMLBatchInferencingServer',
    'AzureMLOnlineInferencingServer',
    'AzureOpenAiFineTuning',
    'AzureOpenAiHyperParameters',
    'BanditPolicy',
    'BaseEnvironmentId',
    'BaseEnvironmentSource',
    'BatchDeployment',
    'BatchDeploymentConfiguration',
    'BatchDeploymentProperties',
    'BatchDeploymentTrackedResourceArmPaginatedResult',
    'BatchEndpoint',
    'BatchEndpointDefaults',
    'BatchEndpointProperties',
    'BatchEndpointTrackedResourceArmPaginatedResult',
    'BatchPipelineComponentDeploymentConfiguration',
    'BatchRetrySettings',
    'BayesianSamplingAlgorithm',
    'BindOptions',
    'BlobReferenceForConsumptionDto',
    'BuildContext',
    'CallRateLimit',
    'CapacityConfig',
    'CapacityReservationGroup',
    'CapacityReservationGroupProperties',
    'CapacityReservationGroupTrackedResourceArmPaginatedResult',
    'CategoricalDataDriftMetricThreshold',
    'CategoricalDataQualityMetricThreshold',
    'CategoricalPredictionDriftMetricThreshold',
    'CertificateDatastoreCredentials',
    'CertificateDatastoreSecrets',
    'Classification',
    'ClassificationModelPerformanceMetricThreshold',
    'ClassificationTrainingSettings',
    'ClusterUpdateParameters',
    'CocoExportSummary',
    'CodeConfiguration',
    'CodeContainer',
    'CodeContainerProperties',
    'CodeContainerResourceArmPaginatedResult',
    'CodeVersion',
    'CodeVersionProperties',
    'CodeVersionResourceArmPaginatedResult',
    'CognitiveServiceEndpointDeploymentResourceProperties',
    'CognitiveServicesSku',
    'Collection',
    'ColumnTransformer',
    'CommandJob',
    'CommandJobLimits',
    'ComponentConfiguration',
    'ComponentContainer',
    'ComponentContainerProperties',
    'ComponentContainerResourceArmPaginatedResult',
    'ComponentVersion',
    'ComponentVersionProperties',
    'ComponentVersionResourceArmPaginatedResult',
    'Compute',
    'ComputeInstance',
    'ComputeInstanceApplication',
    'ComputeInstanceAutologgerSettings',
    'ComputeInstanceConnectivityEndpoints',
    'ComputeInstanceContainer',
    'ComputeInstanceCreatedBy',
    'ComputeInstanceDataDisk',
    'ComputeInstanceDataMount',
    'ComputeInstanceEnvironmentInfo',
    'ComputeInstanceLastOperation',
    'ComputeInstanceProperties',
    'ComputeInstanceSchema',
    'ComputeInstanceSshSettings',
    'ComputeInstanceVersion',
    'ComputeRecurrenceSchedule',
    'ComputeResource',
    'ComputeResourceSchema',
    'ComputeRuntimeDto',
    'ComputeSchedules',
    'ComputeSecrets',
    'ComputeStartStopSchedule',
    'ContainerResourceRequirements',
    'ContainerResourceSettings',
    'ContentSafetyEndpointDeploymentResourceProperties',
    'ContentSafetyEndpointResourceProperties',
    'CosmosDbSettings',
    'CreateMonitorAction',
    'Cron',
    'CronTrigger',
    'CsvExportSummary',
    'CustomForecastHorizon',
    'CustomInferencingServer',
    'CustomKeys',
    'CustomKeysWorkspaceConnectionProperties',
    'CustomMetricThreshold',
    'CustomModelFineTuning',
    'CustomModelJobInput',
    'CustomModelJobOutput',
    'CustomMonitoringSignal',
    'CustomNCrossValidations',
    'CustomSeasonality',
    'CustomService',
    'CustomTargetLags',
    'CustomTargetRollingWindowSize',
    'DataCollector',
    'DataContainer',
    'DataContainerProperties',
    'DataContainerResourceArmPaginatedResult',
    'DataDriftMetricThresholdBase',
    'DataDriftMonitoringSignal',
    'DataFactory',
    'DataImport',
    'DataImportSource',
    'DataLakeAnalytics',
    'DataLakeAnalyticsSchema',
    'DataLakeAnalyticsSchemaProperties',
    'DataPathAssetReference',
    'DataQualityMetricThresholdBase',
    'DataQualityMonitoringSignal',
    'DataReferenceCredential',
    'DataVersionBase',
    'DataVersionBaseProperties',
    'DataVersionBaseResourceArmPaginatedResult',
    'DatabaseSource',
    'Databricks',
    'DatabricksComputeSecrets',
    'DatabricksComputeSecretsProperties',
    'DatabricksProperties',
    'DatabricksSchema',
    'DatasetExportSummary',
    'Datastore',
    'DatastoreCredentials',
    'DatastoreProperties',
    'DatastoreResourceArmPaginatedResult',
    'DatastoreSecrets',
    'DefaultScaleSettings',
    'DeploymentLogs',
    'DeploymentLogsRequest',
    'DeploymentModel',
    'DeploymentResourceConfiguration',
    'DestinationAsset',
    'DiagnoseRequestProperties',
    'DiagnoseResponseResult',
    'DiagnoseResponseResultValue',
    'DiagnoseResult',
    'DiagnoseWorkspaceParameters',
    'DistributionConfiguration',
    'Docker',
    'DockerCredential',
    'EarlyTerminationPolicy',
    'EncryptionKeyVaultUpdateProperties',
    'EncryptionProperty',
    'EncryptionUpdateProperties',
    'Endpoint',
    'EndpointAuthKeys',
    'EndpointAuthToken',
    'EndpointDeploymentModel',
    'EndpointDeploymentPropertiesBase',
    'EndpointDeploymentResourceProperties',
    'EndpointDeploymentResourcePropertiesBasicResource',
    'EndpointDeploymentResourcePropertiesBasicResourceArmPaginatedResult',
    'EndpointKeys',
    'EndpointModels',
    'EndpointPropertiesBase',
    'EndpointResourceProperties',
    'EndpointResourcePropertiesBasicResource',
    'EndpointResourcePropertiesBasicResourceArmPaginatedResult',
    'EndpointScheduleAction',
    'EnvironmentContainer',
    'EnvironmentContainerProperties',
    'EnvironmentContainerResourceArmPaginatedResult',
    'EnvironmentVariable',
    'EnvironmentVersion',
    'EnvironmentVersionProperties',
    'EnvironmentVersionResourceArmPaginatedResult',
    'ErrorAdditionalInfo',
    'ErrorDetail',
    'ErrorResponse',
    'EstimatedVMPrice',
    'EstimatedVMPrices',
    'ExportSummary',
    'ExternalFQDNResponse',
    'FQDNEndpoint',
    'FQDNEndpointDetail',
    'FQDNEndpoints',
    'FQDNEndpointsPropertyBag',
    'Feature',
    'FeatureAttributionDriftMonitoringSignal',
    'FeatureAttributionMetricThreshold',
    'FeatureImportanceSettings',
    'FeatureProperties',
    'FeatureResourceArmPaginatedResult',
    'FeatureStoreSettings',
    'FeatureSubset',
    'FeatureWindow',
    'FeaturesetContainer',
    'FeaturesetContainerProperties',
    'FeaturesetContainerResourceArmPaginatedResult',
    'FeaturesetSpecification',
    'FeaturesetVersion',
    'FeaturesetVersionBackfillRequest',
    'FeaturesetVersionBackfillResponse',
    'FeaturesetVersionProperties',
    'FeaturesetVersionResourceArmPaginatedResult',
    'FeaturestoreEntityContainer',
    'FeaturestoreEntityContainerProperties',
    'FeaturestoreEntityContainerResourceArmPaginatedResult',
    'FeaturestoreEntityVersion',
    'FeaturestoreEntityVersionProperties',
    'FeaturestoreEntityVersionResourceArmPaginatedResult',
    'FeaturizationSettings',
    'FileSystemSource',
    'FineTuningJob',
    'FineTuningVertical',
    'FixedInputData',
    'FlavorData',
    'ForecastHorizon',
    'Forecasting',
    'ForecastingSettings',
    'ForecastingTrainingSettings',
    'FqdnOutboundRule',
    'GenerationSafetyQualityMetricThreshold',
    'GenerationSafetyQualityMonitoringSignal',
    'GenerationTokenUsageMetricThreshold',
    'GenerationTokenUsageSignal',
    'GetBlobReferenceForConsumptionDto',
    'GetBlobReferenceSASRequestDto',
    'GetBlobReferenceSASResponseDto',
    'GridSamplingAlgorithm',
    'GroupStatus',
    'HDInsight',
    'HDInsightProperties',
    'HDInsightSchema',
    'HdfsDatastore',
    'IdAssetReference',
    'IdentityConfiguration',
    'IdentityForCmk',
    'IdleShutdownSetting',
    'Image',
    'ImageClassification',
    'ImageClassificationBase',
    'ImageClassificationMultilabel',
    'ImageInstanceSegmentation',
    'ImageLimitSettings',
    'ImageMetadata',
    'ImageModelDistributionSettings',
    'ImageModelDistributionSettingsClassification',
    'ImageModelDistributionSettingsObjectDetection',
    'ImageModelSettings',
    'ImageModelSettingsClassification',
    'ImageModelSettingsObjectDetection',
    'ImageObjectDetection',
    'ImageObjectDetectionBase',
    'ImageSweepSettings',
    'ImageVertical',
    'ImportDataAction',
    'IndexColumn',
    'InferenceContainerProperties',
    'InferenceEndpoint',
    'InferenceEndpointProperties',
    'InferenceEndpointTrackedResourceArmPaginatedResult',
    'InferenceGroup',
    'InferenceGroupProperties',
    'InferenceGroupTrackedResourceArmPaginatedResult',
    'InferencePool',
    'InferencePoolProperties',
    'InferencePoolTrackedResourceArmPaginatedResult',
    'InferencingServer',
    'InstanceTypeSchema',
    'InstanceTypeSchemaResources',
    'IntellectualProperty',
    'JobBase',
    'JobBaseProperties',
    'JobBaseResourceArmPaginatedResult',
    'JobInput',
    'JobLimits',
    'JobOutput',
    'JobResourceConfiguration',
    'JobScheduleAction',
    'JobService',
    'JupyterKernelConfig',
    'KerberosCredentials',
    'KerberosKeytabCredentials',
    'KerberosKeytabSecrets',
    'KerberosPasswordCredentials',
    'KerberosPasswordSecrets',
    'KeyVaultProperties',
    'Kubernetes',
    'KubernetesOnlineDeployment',
    'KubernetesProperties',
    'KubernetesSchema',
    'LabelCategory',
    'LabelClass',
    'LabelingDataConfiguration',
    'LabelingJob',
    'LabelingJobImageProperties',
    'LabelingJobInstructions',
    'LabelingJobMediaProperties',
    'LabelingJobProperties',
    'LabelingJobResourceArmPaginatedResult',
    'LabelingJobTextProperties',
    'LakeHouseArtifact',
    'ListAmlUserFeatureResult',
    'ListNotebookKeysResult',
    'ListStorageAccountKeysResult',
    'ListUsagesResult',
    'ListWorkspaceKeysResult',
    'ListWorkspaceQuotas',
    'LiteralJobInput',
    'MLAssistConfiguration',
    'MLAssistConfigurationDisabled',
    'MLAssistConfigurationEnabled',
    'MLFlowModelJobInput',
    'MLFlowModelJobOutput',
    'MLTableData',
    'MLTableJobInput',
    'MLTableJobOutput',
    'ManagedComputeIdentity',
    'ManagedIdentity',
    'ManagedIdentityAuthTypeWorkspaceConnectionProperties',
    'ManagedIdentityCredential',
    'ManagedNetworkProvisionOptions',
    'ManagedNetworkProvisionStatus',
    'ManagedNetworkSettings',
    'ManagedOnlineDeployment',
    'ManagedOnlineEndpointDeploymentResourceProperties',
    'ManagedOnlineEndpointResourceProperties',
    'ManagedResourceGroupAssignedIdentities',
    'ManagedResourceGroupSettings',
    'ManagedServiceIdentity',
    'MarketplacePlan',
    'MarketplaceSubscription',
    'MarketplaceSubscriptionProperties',
    'MarketplaceSubscriptionResourceArmPaginatedResult',
    'MaterializationComputeResource',
    'MaterializationSettings',
    'MedianStoppingPolicy',
    'ModelConfiguration',
    'ModelContainer',
    'ModelContainerProperties',
    'ModelContainerResourceArmPaginatedResult',
    'ModelDeprecationInfo',
    'ModelPackageInput',
    'ModelPerformanceMetricThresholdBase',
    'ModelPerformanceSignal',
    'ModelSettings',
    'ModelSku',
    'ModelVersion',
    'ModelVersionProperties',
    'ModelVersionResourceArmPaginatedResult',
    'MonitorComputeConfigurationBase',
    'MonitorComputeIdentityBase',
    'MonitorDefinition',
    'MonitorEmailNotificationSettings',
    'MonitorNotificationSettings',
    'MonitorServerlessSparkCompute',
    'MonitoringDataSegment',
    'MonitoringFeatureFilterBase',
    'MonitoringInputDataBase',
    'MonitoringSignalBase',
    'MonitoringTarget',
    'MonitoringThreshold',
    'MonitoringWorkspaceConnection',
    'Mpi',
    'NCrossValidations',
    'NlpFixedParameters',
    'NlpParameterSubspace',
    'NlpSweepSettings',
    'NlpVertical',
    'NlpVerticalFeaturizationSettings',
    'NlpVerticalLimitSettings',
    'NodeStateCounts',
    'Nodes',
    'NoneAuthTypeWorkspaceConnectionProperties',
    'NoneDatastoreCredentials',
    'NotebookAccessTokenResult',
    'NotebookPreparationError',
    'NotebookResourceInfo',
    'NotificationSetting',
    'NumericalDataDriftMetricThreshold',
    'NumericalDataQualityMetricThreshold',
    'NumericalPredictionDriftMetricThreshold',
    'OAuth2AuthTypeWorkspaceConnectionProperties',
    'Objective',
    'OneLakeArtifact',
    'OneLakeDatastore',
    'OnlineDeployment',
    'OnlineDeploymentProperties',
    'OnlineDeploymentTrackedResourceArmPaginatedResult',
    'OnlineEndpoint',
    'OnlineEndpointProperties',
    'OnlineEndpointTrackedResourceArmPaginatedResult',
    'OnlineInferenceConfiguration',
    'OnlineRequestSettings',
    'OnlineScaleSettings',
    'OpenAIEndpointDeploymentResourceProperties',
    'OpenAIEndpointResourceProperties',
    'Operation',
    'OperationDisplay',
    'OperationListResult',
    'OsPatchingStatus',
    'OutboundRule',
    'OutboundRuleBasicResource',
    'OutboundRuleListResult',
    'OutputPathAssetReference',
    'PATAuthTypeWorkspaceConnectionProperties',
    'PackageInputPathBase',
    'PackageInputPathId',
    'PackageInputPathUrl',
    'PackageInputPathVersion',
    'PackageRequest',
    'PackageResponse',
    'PaginatedComputeResourcesList',
    'PartialBatchDeployment',
    'PartialBatchDeploymentPartialMinimalTrackedResourceWithProperties',
    'PartialJobBase',
    'PartialJobBasePartialResource',
    'PartialManagedServiceIdentity',
    'PartialMinimalTrackedResource',
    'PartialMinimalTrackedResourceWithIdentity',
    'PartialMinimalTrackedResourceWithSku',
    'PartialMinimalTrackedResourceWithSkuAndIdentity',
    'PartialNotificationSetting',
    'PartialRegistryPartialTrackedResource',
    'PartialSku',
    'Password',
    'PendingUploadCredentialDto',
    'PendingUploadRequestDto',
    'PendingUploadResponseDto',
    'PersonalComputeInstanceSettings',
    'PipelineJob',
    'PoolEnvironmentConfiguration',
    'PoolModelConfiguration',
    'PoolStatus',
    'PredictionDriftMetricThresholdBase',
    'PredictionDriftMonitoringSignal',
    'PrivateEndpoint',
    'PrivateEndpointConnection',
    'PrivateEndpointConnectionListResult',
    'PrivateEndpointDestination',
    'PrivateEndpointOutboundRule',
    'PrivateEndpointResource',
    'PrivateLinkResource',
    'PrivateLinkResourceListResult',
    'PrivateLinkServiceConnectionState',
    'ProbeSettings',
    'ProgressMetrics',
    'PropertiesBase',
    'ProxyResource',
    'PyTorch',
    'QueueSettings',
    'QuotaBaseProperties',
    'QuotaUpdateParameters',
    'RandomSamplingAlgorithm',
    'Ray',
    'Recurrence',
    'RecurrenceSchedule',
    'RecurrenceTrigger',
    'RegenerateEndpointKeysRequest',
    'RegenerateServiceAccountKeyContent',
    'Registry',
    'RegistryListCredentialsResult',
    'RegistryPartialManagedServiceIdentity',
    'RegistryPrivateEndpointConnection',
    'RegistryPrivateLinkServiceConnectionState',
    'RegistryRegionArmDetails',
    'RegistryTrackedResourceArmPaginatedResult',
    'Regression',
    'RegressionModelPerformanceMetricThreshold',
    'RegressionTrainingSettings',
    'RequestConfiguration',
    'RequestLogging',
    'RequestMatchPattern',
    'ResizeSchema',
    'Resource',
    'ResourceBase',
    'ResourceConfiguration',
    'ResourceId',
    'ResourceName',
    'ResourceQuota',
    'RollingInputData',
    'Route',
    'SASAuthTypeWorkspaceConnectionProperties',
    'SASCredential',
    'SASCredentialDto',
    'SamplingAlgorithm',
    'SasDatastoreCredentials',
    'SasDatastoreSecrets',
    'ScaleSettings',
    'ScaleSettingsInformation',
    'Schedule',
    'ScheduleActionBase',
    'ScheduleBase',
    'ScheduleProperties',
    'ScheduleResourceArmPaginatedResult',
    'ScriptReference',
    'ScriptsToExecute',
    'Seasonality',
    'SecretConfiguration',
    'ServerlessComputeSettings',
    'ServerlessEndpoint',
    'ServerlessEndpointCapacityReservation',
    'ServerlessEndpointProperties',
    'ServerlessEndpointStatus',
    'ServerlessEndpointTrackedResourceArmPaginatedResult',
    'ServerlessInferenceEndpoint',
    'ServerlessOffer',
    'ServiceManagedResourcesSettings',
    'ServicePrincipalAuthTypeWorkspaceConnectionProperties',
    'ServicePrincipalDatastoreCredentials',
    'ServicePrincipalDatastoreSecrets',
    'ServiceTagDestination',
    'ServiceTagOutboundRule',
    'SetupScripts',
    'SharedPrivateLinkResource',
    'Sku',
    'SkuCapacity',
    'SkuResource',
    'SkuResourceArmPaginatedResult',
    'SkuSetting',
    'SparkJob',
    'SparkJobEntry',
    'SparkJobPythonEntry',
    'SparkJobScalaEntry',
    'SparkResourceConfiguration',
    'SpeechEndpointDeploymentResourceProperties',
    'SpeechEndpointResourceProperties',
    'SslConfiguration',
    'StackEnsembleSettings',
    'StaticInputData',
    'StatusMessage',
    'StorageAccountDetails',
    'SweepJob',
    'SweepJobLimits',
    'SynapseSpark',
    'SynapseSparkProperties',
    'SystemCreatedAcrAccount',
    'SystemCreatedStorageAccount',
    'SystemData',
    'SystemService',
    'TableFixedParameters',
    'TableParameterSubspace',
    'TableSweepSettings',
    'TableVertical',
    'TableVerticalFeaturizationSettings',
    'TableVerticalLimitSettings',
    'TargetLags',
    'TargetRollingWindowSize',
    'TargetUtilizationScaleSettings',
    'TensorFlow',
    'TextClassification',
    'TextClassificationMultilabel',
    'TextNer',
    'ThrottlingRule',
    'TmpfsOptions',
    'TopNFeaturesByAttribution',
    'TrackedResource',
    'TrainingSettings',
    'TrialComponent',
    'TriggerBase',
    'TriggerOnceRequest',
    'TriggerRunSubmissionDto',
    'TritonInferencingServer',
    'TritonModelJobInput',
    'TritonModelJobOutput',
    'TruncationSelectionPolicy',
    'UpdateWorkspaceQuotas',
    'UpdateWorkspaceQuotasResult',
    'UriFileDataVersion',
    'UriFileJobInput',
    'UriFileJobOutput',
    'UriFolderDataVersion',
    'UriFolderJobInput',
    'UriFolderJobOutput',
    'Usage',
    'UsageName',
    'UserAccountCredentials',
    'UserAssignedIdentity',
    'UserCreatedAcrAccount',
    'UserCreatedStorageAccount',
    'UserIdentity',
    'UsernamePasswordAuthTypeWorkspaceConnectionProperties',
    'VirtualMachine',
    'VirtualMachineImage',
    'VirtualMachineSchema',
    'VirtualMachineSchemaProperties',
    'VirtualMachineSecrets',
    'VirtualMachineSecretsSchema',
    'VirtualMachineSize',
    'VirtualMachineSizeListResult',
    'VirtualMachineSshCredentials',
    'VolumeDefinition',
    'VolumeOptions',
    'Webhook',
    'Workspace',
    'WorkspaceConnectionAccessKey',
    'WorkspaceConnectionApiKey',
    'WorkspaceConnectionManagedIdentity',
    'WorkspaceConnectionOAuth2',
    'WorkspaceConnectionPersonalAccessToken',
    'WorkspaceConnectionPropertiesV2',
    'WorkspaceConnectionPropertiesV2BasicResource',
    'WorkspaceConnectionPropertiesV2BasicResourceArmPaginatedResult',
    'WorkspaceConnectionServicePrincipal',
    'WorkspaceConnectionSharedAccessSignature',
    'WorkspaceConnectionUpdateParameter',
    'WorkspaceConnectionUsernamePassword',
    'WorkspaceHubConfig',
    'WorkspaceListResult',
    'WorkspacePrivateEndpointResource',
    'WorkspaceUpdateParameters',
    'ActionType',
    'AllocationState',
    'ApplicationSharingPolicy',
    'AssetProvisioningState',
    'AuthMode',
    'AutoDeleteCondition',
    'AutoRebuildSetting',
    'Autosave',
    'BaseEnvironmentSourceType',
    'BatchDeploymentConfigurationType',
    'BatchLoggingLevel',
    'BatchOutputAction',
    'BillingCurrency',
    'BlockedTransformers',
    'Caching',
    'CategoricalDataDriftMetric',
    'CategoricalDataQualityMetric',
    'CategoricalPredictionDriftMetric',
    'ClassificationModelPerformanceMetric',
    'ClassificationModels',
    'ClassificationMultilabelPrimaryMetrics',
    'ClassificationPrimaryMetrics',
    'ClusterPurpose',
    'ComputeInstanceAuthorizationType',
    'ComputeInstanceState',
    'ComputePowerAction',
    'ComputeRecurrenceFrequency',
    'ComputeTriggerType',
    'ComputeType',
    'ComputeWeekDay',
    'ConnectionAuthType',
    'ConnectionCategory',
    'ConnectionGroup',
    'ContainerType',
    'CreatedByType',
    'CredentialsType',
    'DataAvailabilityStatus',
    'DataCollectionMode',
    'DataImportSourceType',
    'DataReferenceCredentialType',
    'DataType',
    'DatastoreType',
    'DefaultResourceProvisioningState',
    'DeploymentModelVersionUpgradeOption',
    'DeploymentProvisioningState',
    'DiagnoseResultLevel',
    'DistributionType',
    'EarlyTerminationPolicyType',
    'EgressPublicNetworkAccessType',
    'EmailNotificationEnableType',
    'EncryptionStatus',
    'EndpointAuthMode',
    'EndpointComputeType',
    'EndpointProvisioningState',
    'EndpointServiceConnectionStatus',
    'EndpointType',
    'EnvironmentType',
    'EnvironmentVariableType',
    'ExportFormatType',
    'FeatureAttributionMetric',
    'FeatureDataType',
    'FeatureImportanceMode',
    'FeatureLags',
    'FeaturizationMode',
    'FineTuningTaskType',
    'ForecastHorizonMode',
    'ForecastingModels',
    'ForecastingPrimaryMetrics',
    'GenerationSafetyQualityMetric',
    'GenerationTokenUsageMetric',
    'Goal',
    'IdentityConfigurationType',
    'ImageAnnotationType',
    'ImageType',
    'IncrementalDataRefresh',
    'InferencingServerType',
    'InputDeliveryMode',
    'InputPathType',
    'InstanceSegmentationPrimaryMetrics',
    'IsolationMode',
    'JobInputType',
    'JobLimitsType',
    'JobOutputType',
    'JobProvisioningState',
    'JobStatus',
    'JobTier',
    'JobType',
    'KeyType',
    'LearningRateScheduler',
    'ListViewType',
    'LoadBalancerType',
    'LogTrainingMetrics',
    'LogValidationLoss',
    'LogVerbosity',
    'MLAssistConfigurationType',
    'MLFlowAutologgerState',
    'ManagedNetworkStatus',
    'ManagedServiceIdentityType',
    'MarketplaceSubscriptionProvisioningState',
    'MarketplaceSubscriptionStatus',
    'MaterializationStoreType',
    'MediaType',
    'MlflowAutologger',
    'ModelLifecycleStatus',
    'ModelProvider',
    'ModelSize',
    'ModelTaskType',
    'MonitorComputeIdentityType',
    'MonitorComputeType',
    'MonitoringFeatureDataType',
    'MonitoringFeatureFilterType',
    'MonitoringInputDataType',
    'MonitoringModelType',
    'MonitoringNotificationType',
    'MonitoringSignalType',
    'MountAction',
    'MountMode',
    'MountState',
    'MultiSelect',
    'NCrossValidationsMode',
    'Network',
    'NlpLearningRateScheduler',
    'NodeState',
    'NodesValueType',
    'NumericalDataDriftMetric',
    'NumericalDataQualityMetric',
    'NumericalPredictionDriftMetric',
    'ObjectDetectionPrimaryMetrics',
    'OneLakeArtifactType',
    'OperatingSystemType',
    'OperationName',
    'OperationStatus',
    'OperationTrigger',
    'OrderString',
    'Origin',
    'OsType',
    'OutputDeliveryMode',
    'PackageBuildState',
    'PackageInputDeliveryMode',
    'PackageInputType',
    'PatchStatus',
    'PendingUploadCredentialType',
    'PendingUploadType',
    'PoolProvisioningState',
    'PrivateEndpointConnectionProvisioningState',
    'ProtectionLevel',
    'Protocol',
    'ProvisioningState',
    'ProvisioningStatus',
    'PublicNetworkAccessType',
    'QuotaUnit',
    'RandomSamplingAlgorithmRule',
    'RecurrenceFrequency',
    'ReferenceType',
    'RegressionModelPerformanceMetric',
    'RegressionModels',
    'RegressionPrimaryMetrics',
    'RemoteLoginPortPublicAccess',
    'RollingRateType',
    'RuleAction',
    'RuleCategory',
    'RuleStatus',
    'RuleType',
    'SamplingAlgorithmType',
    'ScaleType',
    'ScheduleActionType',
    'ScheduleListViewType',
    'ScheduleProvisioningState',
    'ScheduleProvisioningStatus',
    'ScheduleStatus',
    'ScheduleType',
    'SeasonalityMode',
    'SecretsType',
    'ServerlessEndpointState',
    'ServerlessInferenceEndpointAuthMode',
    'ServiceAccountKeyName',
    'ServiceDataAccessAuthIdentity',
    'ShortSeriesHandlingConfiguration',
    'SkuScaleType',
    'SkuTier',
    'SourceType',
    'SparkJobEntryType',
    'SshPublicAccess',
    'SslConfigStatus',
    'StackMetaLearnerType',
    'Status',
    'StatusMessageLevel',
    'StochasticOptimizer',
    'StorageAccountType',
    'TargetAggregationFunction',
    'TargetLagsMode',
    'TargetRollingWindowSizeMode',
    'TaskType',
    'TextAnnotationType',
    'TrainingMode',
    'TriggerType',
    'UnderlyingResourceAction',
    'UnitOfMeasure',
    'UsageUnit',
    'UseStl',
    'VMPriceOSType',
    'VMTier',
    'ValidationMetricType',
    'VmPriority',
    'VolumeDefinitionType',
    'WebhookType',
    'WeekDay',
]



import pytest

from azure.ai.ml._restclient.v2023_04_01_preview.models import TableVerticalLimitSettings as RestTabularLimitSettings
from azure.ai.ml.entities._job.automl.tabular import TabularLimitSettings


@pytest.mark.automl_test
@pytest.mark.unittest
class TestLimitSettings:
    @pytest.mark.parametrize(
        "scenario",
        [
            "default",
            "max_nodes",
        ],
    )
    def test_limit_from_rest(self, scenario):
        limit_settings_rest = self._get_rest_obj(scenario)
        limit_settings_obj = TabularLimitSettings._from_rest_object(limit_settings_rest)
        assert limit_settings_obj == self._get_entity_obj(scenario), "actual: {}, expected: {}".format(
            limit_settings_obj, self._get_entity_obj(scenario)
        )

    @pytest.mark.parametrize(
        "scenario",
        [
            "default",
            "max_nodes",
        ],
    )
    def test_limit_to_rest(self, scenario):
        limit_settings_obj = self._get_entity_obj(scenario)
        limit_settings_rest = limit_settings_obj._to_rest_object()
        assert limit_settings_rest == self._get_rest_obj(scenario), "actual: {}, expected: {}".format(
            limit_settings_rest, self._get_rest_obj(scenario)
        )

    @pytest.mark.parametrize(
        "scenario",
        [
            "default",
            "max_nodes",
        ],
    )
    def test_equality(self, scenario):
        limit_settings_obj = self._get_entity_obj(scenario)
        # serialize and deserialize to ensure equality
        limit_settings_rest = TabularLimitSettings._to_rest_object(limit_settings_obj)
        limit_settings_obj_2 = TabularLimitSettings._from_rest_object(limit_settings_rest)
        assert limit_settings_obj == limit_settings_obj_2, "actual: {}, expected: {}".format(
            limit_settings_obj, limit_settings_obj_2
        )

    def _get_rest_obj(self, scenario):
        rest_objs = {
            "default": RestTabularLimitSettings(
                enable_early_termination=True,
                exit_score=0.5,
                max_concurrent_trials=10,
                max_cores_per_trial=2,
                max_trials=100,
                timeout="PT10H",
                trial_timeout="PT20M",
                max_nodes=None,
            ),
            "max_nodes": RestTabularLimitSettings(
                enable_early_termination=True,
                exit_score=0.5,
                max_concurrent_trials=10,
                max_cores_per_trial=2,
                max_trials=100,
                timeout="PT10H",
                trial_timeout="PT20M",
                max_nodes=4,
            ),
        }
        return rest_objs[scenario]

    def _get_entity_obj(self, scenario):
        entity_objs = {
            "default": TabularLimitSettings(
                enable_early_termination=True,
                exit_score=0.5,
                max_concurrent_trials=10,
                max_cores_per_trial=2,
                max_trials=100,
                timeout_minutes=600,
                trial_timeout_minutes=20,
                max_nodes=None,
            ),
            "max_nodes": TabularLimitSettings(
                enable_early_termination=True,
                exit_score=0.5,
                max_concurrent_trials=10,
                max_cores_per_trial=2,
                max_trials=100,
                timeout_minutes=600,
                trial_timeout_minutes=20,
                max_nodes=4,
            ),
        }
        return entity_objs[scenario]



from pathlib import Path

import pytest
import yaml
from marshmallow.exceptions import ValidationError
from test_utilities.utils import verify_entity_load_and_dump

from azure.ai.ml import load_model
from azure.ai.ml._restclient.v2021_10_01_dataplanepreview.models import ModelVersionData
from azure.ai.ml._schema import ModelSchema
from azure.ai.ml.constants._common import BASE_PATH_CONTEXT_KEY, AssetTypes
from azure.ai.ml.entities._assets import Model
from azure.ai.ml.entities._util import load_from_dict


@pytest.mark.unittest
@pytest.mark.production_experiences_test
class TestModelSchema:
    def test_deserialize_and_serialize(self) -> None:
        path = Path("./tests/test_configs/model/model_full.yml")

        def simple_model_validation(model):
            assert str(model.path).endswith("lightgbm_mlflow_model")
            assert model.type == AssetTypes.MLFLOW_MODEL

        verify_entity_load_and_dump(load_model, simple_model_validation, path)

    def test_deserialize_no_version(self) -> None:
        path = Path("./tests/test_configs/model/model_no_version.yml")
        model = load_model(path)
        assert model.version is None
        assert model._auto_increment_version
        assert model.type == AssetTypes.CUSTOM_MODEL  # assert the default model type

    def test_deserialize_with_stage(self) -> None:
        path = Path("./tests/test_configs/model/model_with_stage.yml")
        model = load_model(path)
        assert model.stage == "Production"

    def test_deserialize_with_system_metadata(self) -> None:
        path = Path("./tests/test_configs/model/model_with_system_metadata.yml")
        model = load_model(path)
        assert model._system_metadata
        assert model._system_metadata["publisher"] == "Contoso"
        assert model._system_metadata["license"] == "MIT License"

        model_version_resource = model._to_rest_object()
        assert model_version_resource.properties.system_metadata
        assert model_version_resource.properties.system_metadata["publisher"] == "Contoso"
        assert model_version_resource.properties.system_metadata["license"] == "MIT License"

    def test_ipp_model(self) -> None:
        rest_ipp_model = {
            "id": "azureml://registries/fake_registry/models/fake_ipp_model/versions/611575",
            "name": "ada",
            "type": "models",
            "properties": {
                "description": "a description",
                "tags": {},
                "properties": {},
                "isArchived": False,
                "isAnonymous": False,
                "flavors": {},
                "modelType": "custom_model",
                "modelUri": "azureml://datastore/fake_datastore/paths/fake_model_uri",
                "originAssetId": "fake_origin_asset_id",
                "jobName": "fake_job_name",
                "intellectualProperty": {
                    "publisher": "Contoso",
                    "protectionLevel": "All",
                },
            },
            "systemData": {},
        }

        from_rest_ipp_model = Model._from_rest_object(ModelVersionData.deserialize(rest_ipp_model))

        assert from_rest_ipp_model._intellectual_property
        assert from_rest_ipp_model._intellectual_property.protection_level == "All"
        assert from_rest_ipp_model._intellectual_property.publisher == "Contoso"

        ipp_model_dict = from_rest_ipp_model._to_dict()
        assert ipp_model_dict["intellectual_property"]
        assert ipp_model_dict["intellectual_property"]["protection_level"] == "all"
        assert ipp_model_dict["intellectual_property"]["publisher"] == "Contoso"



# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

__path__ = __import__("pkgutil").extend_path(__path__, __name__)  # type: ignore

from .workspace import WorkspaceSchema
from .ai_workspaces.project import ProjectSchema
from .ai_workspaces.hub import HubSchema

__all__ = ["WorkspaceSchema", "ProjectSchema", "HubSchema"]
